@@ -1,8 +1,11 @@
 """Exception handling module"""
+# Standard Library
 from functools import wraps
+from gettext import gettext as _
 
 
 class LutrisError(Exception):
+
     """Base exception for Lutris related errors"""
 
     def __init__(self, message):
@@ -11,14 +14,16 @@ class LutrisError(Exception):
 
 
 class GameConfigError(LutrisError):
+
     """Throw this error when the game configuration prevents the game from
     running properly.
     """
 
 
 class UnavailableLibraries(RuntimeError):
+
     def __init__(self, libraries):
-        message = (
+        message = _(
             "Some required libraries are not installed on your system, install them "
             "with your package manager and restart Lutris. Libraries: %s"
         ) % ", ".join(libraries)
