@@ -1,31 +1,38 @@
 """Module that actually runs the games."""
-import os
+
+# Standard Library
+# pylint: disable=too-many-public-methods
 import json
-import time
+import os
 import shlex
 import subprocess
+import time
+from gettext import gettext as _
 
-from gi.repository import GLib, Gtk, GObject
+# Third Party Libraries
+from gi.repository import GLib, GObject, Gtk
 
-from lutris import pga
-from lutris import runtime
-from lutris.exceptions import GameConfigError, watch_lutris_errors
-from lutris.util import xdgshortcuts
-from lutris.runners import import_runner, InvalidRunner, wine
-from lutris.util import audio, display, jobs, system, strings
-from lutris.util.log import logger
-from lutris.config import LutrisConfig
+# Lutris Modules
+from lutris import pga, runtime
 from lutris.command import MonitoredCommand
-from lutris.gui import dialogs
-from lutris.util.timer import Timer
-from lutris.util.linux import LINUX_SYSTEM
+from lutris.config import LutrisConfig
 from lutris.discord import DiscordPresence
+from lutris.exceptions import GameConfigError, watch_lutris_errors
+from lutris.gui import dialogs
+from lutris.runners import InvalidRunner, import_runner, wine
 from lutris.settings import DEFAULT_DISCORD_CLIENT_ID
+from lutris.util import audio, jobs, strings, system, xdgshortcuts
+from lutris.util.display import DISPLAY_MANAGER, disable_compositing, enable_compositing, restore_gamma
+from lutris.util.graphics.xrandr import turn_off_except
+from lutris.util.linux import LINUX_SYSTEM
+from lutris.util.log import logger
+from lutris.util.timer import Timer
 
 HEARTBEAT_DELAY = 2000
 
 
 class Game(GObject.Object):
+
     """This class takes cares of loading the configuration for a game
        and running it.
     """
@@ -35,13 +42,14 @@ class Game(GObject.Object):
     STATE_RUNNING = "running"
 
     __gsignals__ = {
-        "game-error": (GObject.SIGNAL_RUN_FIRST, None, (str,)),
+        "game-error": (GObject.SIGNAL_RUN_FIRST, None, (str, )),
         "game-start": (GObject.SIGNAL_RUN_FIRST, None, ()),
         "game-started": (GObject.SIGNAL_RUN_FIRST, None, ()),
         "game-stop": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-stopped": (GObject.SIGNAL_RUN_FIRST, None, (int,)),
+        "game-stopped": (GObject.SIGNAL_RUN_FIRST, None, (int, )),
         "game-removed": (GObject.SIGNAL_RUN_FIRST, None, ()),
         "game-updated": (GObject.SIGNAL_RUN_FIRST, None, ()),
+        "game-installed": (GObject.SIGNAL_RUN_FIRST, None, ()),
     }
 
     def __init__(self, game_id=None):
@@ -79,18 +87,25 @@ class Game(GObject.Object):
         self.heartbeat = None
         self.killswitch = None
         self.state = self.STATE_IDLE
-        self.exit_main_loop = False
-        self.xboxdrv_thread = None
         self.game_runtime_config = {}
         self.resolution_changed = False
         self.compositor_disabled = False
-        self.stop_compositor = self.start_compositor = ""
         self.original_outputs = None
         self._log_buffer = None
         self.timer = Timer()
 
+    def __repr__(self):
+        return self.__str__()
+
+    def __str__(self):
+        value = self.name
+        if self.runner_name:
+            value += " (%s)" % self.runner_name
+        return value
+
     @property
     def log_buffer(self):
+        """Access the log buffer object, creating it if necessary"""
         if self._log_buffer is None:
             self._log_buffer = Gtk.TextBuffer()
             self._log_buffer.create_tag("warning", foreground="red")
@@ -99,15 +114,6 @@ class Game(GObject.Object):
                 self._log_buffer.set_text(self.game_thread.stdout)
         return self._log_buffer
 
-    def __repr__(self):
-        return self.__unicode__()
-
-    def __unicode__(self):
-        value = self.name
-        if self.runner_name:
-            value += " (%s)" % self.runner_name
-        return value
-
     @property
     def formatted_playtime(self):
         """Return a human readable formatted play time"""
@@ -115,6 +121,9 @@ class Game(GObject.Object):
 
     @property
     def is_search_result(self):
+        """Return whether or not the game is a remote game from search results.
+        This is bad, find another way to do this.
+        """
         return self.id < 0
 
     @staticmethod
@@ -124,25 +133,28 @@ class Game(GObject.Object):
             message_text = message["text"].replace("&", "&amp;")
             dialogs.ErrorDialog(message_text)
         elif message["error"] == "RUNNER_NOT_INSTALLED":
-            dialogs.ErrorDialog("Error the runner is not installed")
+            dialogs.ErrorDialog(_("Error the runner is not installed"))
         elif message["error"] == "NO_BIOS":
-            dialogs.ErrorDialog("A bios file is required to run this game")
+            dialogs.ErrorDialog(_("A bios file is required to run this game"))
         elif message["error"] == "FILE_NOT_FOUND":
             filename = message["file"]
             if filename:
-                message_text = "The file {} could not be found".format(
-                    filename.replace("&", "&amp;")
-                )
+                message_text = _("The file {} could not be found").format(filename.replace("&", "&amp;"))
             else:
-                message_text = "No file provided"
+                message_text = _("No file provided")
             dialogs.ErrorDialog(message_text)
         elif message["error"] == "NOT_EXECUTABLE":
             message_text = message["file"].replace("&", "&amp;")
-            dialogs.ErrorDialog("The file %s is not executable" % message_text)
+            dialogs.ErrorDialog(_("The file %s is not executable") % message_text)
+        elif message["error"] == "PATH_NOT_SET":
+            message_text = _("The path '%s' is not set. please set it in the options.") % message["path"]
+            dialogs.ErrorDialog(message_text)
+        else:
+            dialogs.ErrorDialog(_("Unhandled error: %s") % message["error"])
 
     def get_browse_dir(self):
         """Return the path to open with the Browse Files action."""
-        return self.runner.browse_dir
+        return self.runner.game_path
 
     def _get_runner(self):
         """Return the runner instance for this game's configuration"""
@@ -150,51 +162,47 @@ class Game(GObject.Object):
             runner_class = import_runner(self.runner_name)
             return runner_class(self.config)
         except InvalidRunner:
-            logger.error(
-                "Unable to import runner %s for %s", self.runner_name, self.slug
-            )
+            logger.error("Unable to import runner %s for %s", self.runner_name, self.slug)
 
     def load_config(self):
         """Load the game's configuration."""
         if not self.is_installed:
             return
-        self.config = LutrisConfig(
-            runner_slug=self.runner_name, game_config_id=self.game_config_id
-        )
+        self.config = LutrisConfig(runner_slug=self.runner_name, game_config_id=self.game_config_id)
         self.runner = self._get_runner()
         if self.discord_presence.available:
             self.discord_presence.client_id = (
-                self.config.system_config.get("discord_client_id")
-                or DEFAULT_DISCORD_CLIENT_ID
-            )
-            self.discord_presence.game_name = (
-                self.config.system_config.get("discord_custom_game_name") or self.name
-            )
-            self.discord_presence.show_runner = self.config.system_config.get(
-                "discord_show_runner", True
+                self.config.system_config.get("discord_client_id") or DEFAULT_DISCORD_CLIENT_ID
             )
+            self.discord_presence.game_name = (self.config.system_config.get("discord_custom_game_name") or self.name)
+            self.discord_presence.show_runner = self.config.system_config.get("discord_show_runner", True)
             self.discord_presence.runner_name = (
-                self.config.system_config.get("discord_custom_runner_name")
-                or self.runner_name
-            )
-            self.discord_presence.rpc_enabled = self.config.system_config.get(
-                "discord_rpc_enabled", True
+                self.config.system_config.get("discord_custom_runner_name") or self.runner_name
             )
+            self.discord_presence.rpc_enabled = self.config.system_config.get("discord_rpc_enabled", True)
 
     def set_desktop_compositing(self, enable):
         """Enables or disables compositing"""
         if enable:
-            system.execute(self.start_compositor, shell=True)
+            if self.compositor_disabled:
+                enable_compositing()
+                self.compositor_disabled = False
         else:
-            (
-                self.start_compositor,
-                self.stop_compositor,
-            ) = display.get_compositor_commands()
-            if not (self.compositor_disabled or not self.stop_compositor):
-                system.execute(self.stop_compositor, shell=True)
+            if not self.compositor_disabled:
+                disable_compositing()
                 self.compositor_disabled = True
 
     def remove(self, from_library=False, from_disk=False):
+        """Uninstall a game
+
+        Params:
+            from_library (bool): Completely remove the game from library, do
+                                 not set it as uninstalled
+            from_disk (bool): Delete the game files
+
+        Return:
+            bool: Updated value for from_library
+        """
         if from_disk and self.runner:
             logger.debug("Removing game %s from disk", self.id)
             self.runner.remove_game_data(game_path=self.directory)
@@ -251,7 +259,7 @@ class Game(GObject.Object):
         )
         self.emit("game-updated")
 
-    def prelaunch(self):
+    def is_launchable(self):
         """Verify that the current game can be launched."""
         if not self.runner.is_installed():
             installed = self.runner.install_dialog()
@@ -262,15 +270,8 @@ class Game(GObject.Object):
             runtime_updater = runtime.RuntimeUpdater()
             if runtime_updater.is_updating():
                 logger.warning("Runtime updates: %s", runtime_updater.current_updates)
-                dialogs.ErrorDialog(
-                    "Runtime currently updating", "Game might not work as expected"
-                )
-        if (
-            "wine" in self.runner_name
-            and not wine.get_system_wine_version()
-            and not LINUX_SYSTEM.is_flatpak
-        ):
-
+                dialogs.ErrorDialog(_("Runtime currently updating"), _("Game might not work as expected"))
+        if ("wine" in self.runner_name and not wine.get_system_wine_version() and not LINUX_SYSTEM.is_flatpak):
             # TODO find a reference to the root window or better yet a way not
             # to have Gtk dependent code in this class.
             root_window = None
@@ -280,47 +281,37 @@ class Game(GObject.Object):
     def play(self):
         """Launch the game."""
         if not self.runner:
-            dialogs.ErrorDialog("Invalid game configuration: Missing runner")
+            dialogs.ErrorDialog(_("Invalid game configuration: Missing runner"))
             self.state = self.STATE_STOPPED
             self.emit("game-stop")
             return
 
-        if not self.prelaunch():
+        if not self.is_launchable():
             self.state = self.STATE_STOPPED
             self.emit("game-stop")
             return
 
         self.emit("game-start")
-        if hasattr(self.runner, "prelaunch"):
-            logger.debug("Prelaunching %s", self.runner)
-            try:
-                jobs.AsyncCall(self.runner.prelaunch, self.configure_game)
-            except Exception as ex:
-                logger.error(ex)
-                raise
-
-        else:
-            self.configure_game(True)
+        jobs.AsyncCall(self.runner.prelaunch, self.configure_game)
 
     @watch_lutris_errors
-    def configure_game(self, prelaunched, error=None):
+    def configure_game(self, prelaunched, error=None):  # noqa: C901
         """Get the game ready to start, applying all the options
         This methods sets the game_runtime_config attribute.
         """
-
+        # pylint: disable=too-many-locals,too-many-branches,too-many-statements
+        # TODO: split into multiple methods to reduce complexity (42)
         if error:
             logger.error(error)
             dialogs.ErrorDialog(str(error))
         if not prelaunched:
             logger.error("Game prelaunch unsuccessful")
-            dialogs.ErrorDialog("An error prevented the game from running")
+            dialogs.ErrorDialog(_("An error prevented the game from running"))
             self.state = self.STATE_STOPPED
             self.emit("game-stop")
             return
         system_config = self.runner.system_config
-        self.original_outputs = sorted(
-            display.get_outputs(), key=lambda e: e.name == system_config.get("display")
-        )
+        self.original_outputs = DISPLAY_MANAGER.get_config()
 
         gameplay_info = self.runner.play()
         if "error" in gameplay_info:
@@ -328,8 +319,8 @@ class Game(GObject.Object):
             self.state = self.STATE_STOPPED
             self.emit("game-stop")
             return
-        logger.debug("Launching %s: %s", self.name, gameplay_info)
-        logger.debug("Game info: %s", json.dumps(gameplay_info, indent=2))
+        logger.debug("Launching %s", self.name)
+        logger.debug(json.dumps(gameplay_info, indent=2))
 
         env = {}
         sdl_gamecontrollerconfig = system_config.get("sdl_gamecontrollerconfig")
@@ -363,13 +354,13 @@ class Game(GObject.Object):
                     logger.warning("Selected display %s not found", restrict_to_display)
                     restrict_to_display = None
             if restrict_to_display:
-                display.turn_off_except(restrict_to_display)
+                turn_off_except(restrict_to_display)
                 time.sleep(3)
                 self.resolution_changed = True
 
         resolution = system_config.get("resolution")
         if resolution != "off":
-            display.change_resolution(resolution)
+            DISPLAY_MANAGER.set_resolution(resolution)
             time.sleep(3)
             self.resolution_changed = True
 
@@ -397,9 +388,7 @@ class Game(GObject.Object):
         xephyr = system_config.get("xephyr") or "off"
         if xephyr != "off":
             if not system.find_executable("Xephyr"):
-                raise GameConfigError(
-                    "Unable to find Xephyr, install it or disable the Xephyr option"
-                )
+                raise GameConfigError("Unable to find Xephyr, install it or disable the Xephyr option")
 
             xephyr_depth = "8" if xephyr == "8bpp" else "16"
             xephyr_resolution = system_config.get("xephyr_resolution") or "640x480"
@@ -425,11 +414,12 @@ class Game(GObject.Object):
             setxkbmap_command = ["setxkbmap", "-model", "pc101", "us", "-print"]
             xkbcomp_command = ["xkbcomp", "-", os.environ.get("DISPLAY", ":0")]
             xkbcomp = subprocess.Popen(xkbcomp_command, stdin=subprocess.PIPE)
-            subprocess.Popen(
-                setxkbmap_command, env=os.environ, stdout=xkbcomp.stdin
-            ).communicate()
+            subprocess.Popen(setxkbmap_command, env=os.environ, stdout=xkbcomp.stdin).communicate()
             xkbcomp.communicate()
 
+        if system_config.get("aco"):
+            env["RADV_PERFTEST"] = "aco"
+
         pulse_latency = system_config.get("pulse_latency")
         if pulse_latency:
             env["PULSE_LATENCY_MSEC"] = "60"
@@ -444,15 +434,11 @@ class Game(GObject.Object):
             if strangle_cmd:
                 launch_arguments = [strangle_cmd, fps_limit] + launch_arguments
             else:
-                logger.warning(
-                    "libstrangle is not available on this system, FPS limiter disabled"
-                )
+                logger.warning("libstrangle is not available on this system, FPS limiter disabled")
 
         prefix_command = system_config.get("prefix_command") or ""
         if prefix_command:
-            launch_arguments = (
-                shlex.split(os.path.expandvars(prefix_command)) + launch_arguments
-            )
+            launch_arguments = (shlex.split(os.path.expandvars(prefix_command)) + launch_arguments)
 
         single_cpu = system_config.get("single_cpu") or False
         if single_cpu:
@@ -465,11 +451,7 @@ class Game(GObject.Object):
         if terminal:
             terminal = system_config.get("terminal_app", system.get_default_terminal())
             if terminal and not system.find_executable(terminal):
-                dialogs.ErrorDialog(
-                    "The selected terminal application "
-                    "could not be launched:\n"
-                    "%s" % terminal
-                )
+                dialogs.ErrorDialog(_("The selected terminal application could not be launched:\n%s") % terminal)
                 self.state = self.STATE_STOPPED
                 self.emit("game-stop")
                 return
@@ -492,15 +474,15 @@ class Game(GObject.Object):
             env["LD_PRELOAD"] = ld_preload
 
         # Feral gamemode
-        gamemode = system_config.get("gamemode")
+        gamemode = system_config.get("gamemode") and LINUX_SYSTEM.gamemode_available()
         if gamemode:
-            env["LD_PRELOAD"] = ":".join(
-                [
-                    path
-                    for path in [env.get("LD_PRELOAD"), "libgamemodeauto.so", ]
-                    if path
-                ]
-            )
+            if system.find_executable("gamemoderun"):
+                launch_arguments.insert(0, "gamemoderun")
+            else:
+                env["LD_PRELOAD"] = ":".join([path for path in [
+                    env.get("LD_PRELOAD"),
+                    "libgamemodeauto.so",
+                ] if path])
 
         # LD_LIBRARY_PATH
         game_ld_libary_path = gameplay_info.get("ld_library_path")
@@ -524,29 +506,28 @@ class Game(GObject.Object):
         if system_config.get("disable_compositor"):
             self.set_desktop_compositing(False)
 
-        # xboxdrv setup
-        xboxdrv_config = system_config.get("xboxdrv")
-        if xboxdrv_config:
-            self.xboxdrv_start(xboxdrv_config)
-
         prelaunch_command = system_config.get("prelaunch_command")
-        if system.path_exists(prelaunch_command):
-            self.prelaunch_executor = MonitoredCommand(
-                [prelaunch_command],
-                include_processes=[os.path.basename(prelaunch_command)],
-                env=self.game_runtime_config["env"],
-                cwd=self.directory,
-            )
-            self.prelaunch_executor.start()
-            logger.info("Running %s in the background", prelaunch_command)
+        if prelaunch_command:
+            command_array = shlex.split(prelaunch_command)
+            if system.path_exists(command_array[0]):
+                self.prelaunch_executor = MonitoredCommand(
+                    command_array,
+                    include_processes=[os.path.basename(command_array[0])],
+                    env=self.game_runtime_config["env"],
+                    cwd=self.directory,
+                )
+                self.prelaunch_executor.start()
+                logger.info("Running %s in the background", prelaunch_command)
         if system_config.get("prelaunch_wait"):
             self.heartbeat = GLib.timeout_add(HEARTBEAT_DELAY, self.prelaunch_beat)
         else:
             self.start_game()
 
     def start_game(self):
+        """Run a background command to lauch the game"""
         self.game_thread = MonitoredCommand(
             self.game_runtime_config["args"],
+            title=self.name,
             runner=self.runner,
             env=self.game_runtime_config["env"],
             term=self.game_runtime_config["terminal"],
@@ -563,42 +544,13 @@ class Game(GObject.Object):
         self.heartbeat = GLib.timeout_add(HEARTBEAT_DELAY, self.beat)
 
     def stop_game(self):
+        """Cleanup after a game as stopped"""
         self.state = self.STATE_STOPPED
         self.emit("game-stop")
         if not self.timer.finished:
             self.timer.end()
             self.playtime += self.timer.duration / 3600
 
-    def xboxdrv_start(self, config):
-        command = [
-            "pkexec",
-            "xboxdrv",
-            "--daemon",
-            "--detach-kernel-driver",
-            "--dbus",
-            "session",
-            "--silent",
-        ] + shlex.split(config)
-        logger.debug("[xboxdrv] %s", " ".join(command))
-        self.xboxdrv_thread = MonitoredCommand(command, include_processes=["xboxdrv"])
-        self.xboxdrv_thread.stop_func = self.xboxdrv_stop
-        self.xboxdrv_thread.start()
-
-    @staticmethod
-    def reload_xpad():
-        """Reloads the xpads module.
-        The path is hardcoded because this script is allowed to be executed as
-        root with a PolicyKit rule put in place by the packages.
-        Note to packagers: If you don't intend to create a PolicyKit rule for
-        this script then don't package it as calling it will fail.
-        """
-        if system.path_exists("/usr/share/lutris/bin/resetxpad"):
-            os.system("pkexec /usr/share/lutris/bin/resetxpad")
-
-    def xboxdrv_stop(self):
-        os.system("pkexec xboxdrvctl --shutdown")
-        self.reload_xpad()
-
     def prelaunch_beat(self):
         """Watch the prelaunch command"""
         if self.prelaunch_executor and self.prelaunch_executor.is_running:
@@ -609,9 +561,7 @@ class Game(GObject.Object):
     def beat(self):
         """Watch the game's process(es)."""
         if self.game_thread.error:
-            dialogs.ErrorDialog(
-                "<b>Error lauching the game:</b>\n" + self.game_thread.error
-            )
+            dialogs.ErrorDialog(_("<b>Error lauching the game:</b>\n") + self.game_thread.error)
             self.on_game_quit()
             return False
 
@@ -635,9 +585,7 @@ class Game(GObject.Object):
             return
 
         logger.info("Stopping %s", self)
-        if self.runner.system_config.get("xboxdrv"):
-            logger.debug("Stopping xboxdrv")
-            self.xboxdrv_thread.stop()
+
         if self.game_thread:
             jobs.AsyncCall(self.game_thread.stop, None)
         self.stop_game()
@@ -656,15 +604,17 @@ class Game(GObject.Object):
 
         # Check for post game script
         postexit_command = self.runner.system_config.get("postexit_command")
-        if system.path_exists(postexit_command):
-            logger.info("Running post-exit command: %s", postexit_command)
-            postexit_thread = MonitoredCommand(
-                [postexit_command],
-                include_processes=[os.path.basename(postexit_command)],
-                env=self.game_runtime_config["env"],
-                cwd=self.directory,
-            )
-            postexit_thread.start()
+        if postexit_command:
+            command_array = shlex.split(postexit_command)
+            if system.path_exists(command_array[0]):
+                logger.info("Running post-exit command: %s", postexit_command)
+                postexit_thread = MonitoredCommand(
+                    command_array,
+                    include_processes=[os.path.basename(postexit_command)],
+                    env=self.game_runtime_config["env"],
+                    cwd=self.directory,
+                )
+                postexit_thread.start()
 
         if self.discord_presence.available:
             self.discord_presence.clear_discord_rich_presence()
@@ -677,7 +627,7 @@ class Game(GObject.Object):
         os.chdir(os.path.expanduser("~"))
 
         if self.resolution_changed or self.runner.system_config.get("reset_desktop"):
-            display.change_resolution(self.original_outputs)
+            DISPLAY_MANAGER.set_resolution(self.original_outputs)
 
         if self.compositor_disabled:
             self.set_desktop_compositing(True)
@@ -686,11 +636,9 @@ class Game(GObject.Object):
             subprocess.Popen(["setxkbmap"], env=os.environ).communicate()
 
         if self.runner.system_config.get("restore_gamma"):
-            display.restore_gamma()
+            restore_gamma()
 
         self.process_return_codes()
-        if self.exit_main_loop:
-            exit()
 
     def process_return_codes(self):
         """Do things depending on how the game quitted."""
@@ -699,18 +647,13 @@ class Game(GObject.Object):
             error = "error while loading shared lib"
             error_line = strings.lookup_string_in_text(error, self.game_thread.stdout)
             if error_line:
-                dialogs.ErrorDialog(
-                    "<b>Error: Missing shared library.</b>" "\n\n%s" % error_line
-                )
+                dialogs.ErrorDialog(_("<b>Error: Missing shared library.</b>\n\n%s") % error_line)
 
         if self.game_thread.return_code == 1:
             # Error Wine version conflict
             error = "maybe the wrong wineserver"
             if strings.lookup_string_in_text(error, self.game_thread.stdout):
-                dialogs.ErrorDialog(
-                    "<b>Error: A different Wine version is "
-                    "already using the same Wine prefix.</b>"
-                )
+                dialogs.ErrorDialog(_("<b>Error: A different Wine version is already using the same Wine prefix.</b>"))
 
     def notify_steam_game_changed(self, appmanifest):
         """Receive updates from Steam games and set the thread's ready state accordingly"""
