@@ -15,54 +15,51 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+# Standard Library
 import json
 import logging
 import os
 import signal
 import sys
-import gettext
-from gettext import gettext as _
 import tempfile
+from gettext import gettext as _
 
 import gi
-
 gi.require_version("Gdk", "3.0")
 gi.require_version("Gtk", "3.0")
 gi.require_version("GnomeDesktop", "3.0")
-
 from gi.repository import Gio, GLib, Gtk
-from lutris import pga
+
+# Lutris Modules
+from lutris import pga, settings
+from lutris.api import parse_installer_url
+from lutris.command import exec_command
 from lutris.game import Game
-from lutris import settings
 from lutris.gui.dialogs import ErrorDialog, InstallOrPlayDialog
 from lutris.gui.dialogs.issue import IssueReportWindow
 from lutris.gui.installerwindow import InstallerWindow
 from lutris.gui.widgets.status_icon import LutrisStatusIcon
 from lutris.migrations import migrate
-from lutris.command import exec_command
-from lutris.util.steam.appmanifest import AppManifest, get_appmanifests
-from lutris.util.steam.config import get_steamapps_paths
-from lutris.util import datapath
-from lutris.util import log
+from lutris.startup import init_lutris, run_all_checks
+from lutris.util import datapath, log
+from lutris.util.http import HTTPError, Request
 from lutris.util.jobs import AsyncCall
 from lutris.util.log import logger
-from lutris.util.http import Request, HTTPError
-from lutris.api import parse_installer_url
-from lutris.startup import init_lutris, run_all_checks
+from lutris.util.steam.appmanifest import AppManifest, get_appmanifests
+from lutris.util.steam.config import get_steamapps_paths
 from lutris.util.wine.dxvk import init_dxvk_versions, wait_for_dxvk_init
 
 from .lutriswindow import LutrisWindow
 
 
 class Application(Gtk.Application):
+
     def __init__(self):
         super().__init__(
             application_id="net.lutris.Lutris",
             flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE,
         )
         init_lutris()
-        gettext.bindtextdomain("lutris", "/usr/share/locale")
-        gettext.textdomain("lutris")
 
         GLib.set_application_name(_("Lutris"))
         self.running_games = Gio.ListStore.new(Game)
@@ -73,88 +70,120 @@ class Application(Gtk.Application):
         self.run_in_background = False
 
         if os.geteuid() == 0:
-            ErrorDialog(
-                "Running Lutris as root is not recommended and may cause unexpected issues"
-            )
+            ErrorDialog(_("Running Lutris as root is not recommended and may cause unexpected issues"))
 
         try:
-            self.css_provider.load_from_path(
-                os.path.join(datapath.get(), "ui", "lutris.css")
-            )
+            self.css_provider.load_from_path(os.path.join(datapath.get(), "ui", "lutris.css"))
         except GLib.Error as e:
             logger.exception(e)
 
         if hasattr(self, "add_main_option"):
             self.add_arguments()
         else:
-            ErrorDialog(
-                "Your Linux distribution is too old. Lutris won't function properly."
-            )
+            ErrorDialog(_("Your Linux distribution is too old. Lutris won't function properly."))
 
     def add_arguments(self):
         if hasattr(self, "set_option_context_summary"):
-            self.set_option_context_summary(
+            self.set_option_context_summary(_(
                 "Run a game directly by adding the parameter lutris:rungame/game-identifier.\n"
                 "If several games share the same identifier you can use the numerical ID "
                 "(displayed when running lutris --list-games) and add "
                 "lutris:rungameid/numerical-id.\n"
                 "To install a game, add lutris:install/game-identifier."
-            )
+            ))
         else:
-            logger.warning(
-                "GLib.set_option_context_summary missing, "
-                "was added in GLib 2.56 (Released 2018-03-12)"
-            )
+            logger.warning("GLib.set_option_context_summary missing, " "was added in GLib 2.56 (Released 2018-03-12)")
         self.add_main_option(
-            "version", ord("v"), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-            _("Print the version of Lutris and exit"), None,
+            "version",
+            ord("v"),
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.NONE,
+            _("Print the version of Lutris and exit"),
+            None,
         )
         self.add_main_option(
-            "debug", ord("d"), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-            _("Show debug messages"), None,
+            "debug",
+            ord("d"),
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.NONE,
+            _("Show debug messages"),
+            None,
         )
         self.add_main_option(
-            "install", ord("i"), GLib.OptionFlags.NONE, GLib.OptionArg.STRING,
-            _("Install a game from a yml file"), None,
+            "install",
+            ord("i"),
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.STRING,
+            _("Install a game from a yml file"),
+            None,
         )
         self.add_main_option(
-            "exec", ord("e"), GLib.OptionFlags.NONE, GLib.OptionArg.STRING,
-            _("Execute a program with the lutris runtime"), None,
+            "exec",
+            ord("e"),
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.STRING,
+            _("Execute a program with the lutris runtime"),
+            None,
         )
         self.add_main_option(
-            "list-games", ord("l"), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-            _("List all games in database"), None,
+            "list-games",
+            ord("l"),
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.NONE,
+            _("List all games in database"),
+            None,
         )
         self.add_main_option(
-            "installed", ord("o"), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-            _("Only list installed games"), None,
+            "installed",
+            ord("o"),
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.NONE,
+            _("Only list installed games"),
+            None,
         )
         self.add_main_option(
-            "list-steam-games", ord("s"), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-            _("List available Steam games"), None,
+            "list-steam-games",
+            ord("s"),
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.NONE,
+            _("List available Steam games"),
+            None,
         )
         self.add_main_option(
-            "list-steam-folders", 0, GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-            _("List all known Steam library folders"), None,
+            "list-steam-folders",
+            0,
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.NONE,
+            _("List all known Steam library folders"),
+            None,
         )
         self.add_main_option(
-            "json", ord("j"), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-            _("Display the list of games in JSON format"), None,
+            "json",
+            ord("j"),
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.NONE,
+            _("Display the list of games in JSON format"),
+            None,
         )
         self.add_main_option(
-            "reinstall", 0, GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-            _("Reinstall game"), None,
+            "reinstall",
+            0,
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.NONE,
+            _("Reinstall game"),
+            None,
         )
+        self.add_main_option("submit-issue", 0, GLib.OptionFlags.NONE, GLib.OptionArg.NONE, _("Submit an issue"), None)
         self.add_main_option(
-            "submit-issue", 0, GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-            _("Submit an issue"), None
-        )
-        self.add_main_option(
-            GLib.OPTION_REMAINING, 0, GLib.OptionFlags.NONE, GLib.OptionArg.STRING_ARRAY,
-            _("uri to open"), "URI",
+            GLib.OPTION_REMAINING,
+            0,
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.STRING_ARRAY,
+            _("uri to open"),
+            "URI",
         )
 
-    def do_startup(self):
+    def do_startup(self):  # pylint: disable=arguments-differ
         Gtk.Application.do_startup(self)
         signal.signal(signal.SIGINT, signal.SIG_DFL)
 
@@ -163,13 +192,11 @@ class Application(Gtk.Application):
         self.add_action(action)
         self.add_accelerator("<Primary>q", "app.quit")
 
-    def do_activate(self):
+    def do_activate(self):  # pylint: disable=arguments-differ
         if not self.window:
             self.window = LutrisWindow(application=self)
             screen = self.window.props.screen
-            Gtk.StyleContext.add_provider_for_screen(
-                screen, self.css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
-            )
+            Gtk.StyleContext.add_provider_for_screen(screen, self.css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
         if not self.run_in_background:
             self.window.present()
         else:
@@ -207,7 +234,10 @@ class Application(Gtk.Application):
         # Workaround broken pygobject bindings
         command_line.do_print_literal(command_line, string + "\n")
 
-    def do_command_line(self, command_line):
+    def do_command_line(self, command_line):  # noqa: C901  # pylint: disable=arguments-differ
+        # pylint: disable=too-many-locals,too-many-return-statements,too-many-branches
+        # pylint: disable=too-many-statements
+        # TODO: split into multiple methods to reduce complexity (35)
         options = command_line.get_options_dict()
 
         # Use stdout to output logs, only if no command line argument is
@@ -245,7 +275,7 @@ class Application(Gtk.Application):
         logger.info("Running Lutris %s", settings.VERSION)
         migrate()
         run_all_checks()
-        AsyncCall(init_dxvk_versions)
+        AsyncCall(init_dxvk_versions, None)
 
         # List game
         if options.contains("list-games"):
@@ -258,21 +288,21 @@ class Application(Gtk.Application):
                 self.print_game_list(command_line, game_list)
             return 0
         # List Steam games
-        elif options.contains("list-steam-games"):
+        if options.contains("list-steam-games"):
             self.print_steam_list(command_line)
             return 0
         # List Steam folders
-        elif options.contains("list-steam-folders"):
+        if options.contains("list-steam-folders"):
             self.print_steam_folders(command_line)
             return 0
 
         # Execute command in Lutris context
-        elif options.contains("exec"):
+        if options.contains("exec"):
             command = options.lookup_value("exec").get_string()
             self.execute_command(command)
             return 0
 
-        elif options.contains("submit-issue"):
+        if options.contains("submit-issue"):
             IssueReportWindow(application=self)
             return 0
 
@@ -280,7 +310,7 @@ class Application(Gtk.Application):
             url = options.lookup_value(GLib.OPTION_REMAINING)
             installer_info = self.get_lutris_action(url)
         except ValueError:
-            self._print(command_line, "%s is not a valid URI" % url.get_strv())
+            self._print(command_line, _("%s is not a valid URI") % url.get_strv())
             return 1
         game_slug = installer_info["game_slug"]
         action = installer_info["action"]
@@ -293,7 +323,7 @@ class Application(Gtk.Application):
                 try:
                     request = Request(installer_file).get()
                 except HTTPError:
-                    self._print(command_line, "Failed to download %s" % installer_file)
+                    self._print(command_line, _("Failed to download %s") % installer_file)
                     return 1
                 try:
                     headers = dict(request.response_headers)
@@ -301,7 +331,8 @@ class Application(Gtk.Application):
                 except (KeyError, IndexError):
                     file_name = os.path.basename(installer_file)
                 file_path = os.path.join(tempfile.gettempdir(), file_name)
-                self._print(command_line, "download %s to %s started" % (installer_file, file_path))
+                self._print(command_line, _("download {url} to {file} started").format(
+                    url=installer_file, file=file_path))
                 with open(file_path, 'wb') as dest_file:
                     dest_file.write(request.content)
                 installer_file = file_path
@@ -311,7 +342,7 @@ class Application(Gtk.Application):
                 action = "install"
 
             if not os.path.isfile(installer_file):
-                self._print(command_line, "No such file: %s" % installer_file)
+                self._print(command_line, _("No such file: %s") % installer_file)
                 return 1
 
         db_game = None
@@ -327,14 +358,11 @@ class Application(Gtk.Application):
             elif action == "install":
                 # Installers can use game or installer slugs
                 self.run_in_background = True
-                db_game = pga.get_game_by_field(
-                    game_slug, "slug"
-                ) or pga.get_game_by_field(game_slug, "installer_slug")
+                db_game = pga.get_game_by_field(game_slug, "slug") or pga.get_game_by_field(game_slug, "installer_slug")
             else:
                 # Dazed and confused, try anything that might works
                 db_game = (
-                    pga.get_game_by_field(game_slug, "id")
-                    or pga.get_game_by_field(game_slug, "slug")
+                    pga.get_game_by_field(game_slug, "id") or pga.get_game_by_field(game_slug, "slug")
                     or pga.get_game_by_field(game_slug, "installer_slug")
                 )
 
@@ -376,7 +404,7 @@ class Application(Gtk.Application):
 
     def launch(self, game):
         """Launch a Lutris game"""
-        logger.debug("Launching %s (%s)", game, id(game))
+        logger.debug("Launching %s", game)
         self.running_games.append(game)
         game.connect("game-stop", self.on_game_stop)
         wait_for_dxvk_init()
@@ -391,12 +419,14 @@ class Application(Gtk.Application):
             game = self.running_games.get_item(i)
             if game.id == game_id:
                 return game
+        return None
 
     def get_game_index(self, game_id):
         for i in range(self.running_games.get_n_items()):
             game = self.running_games.get_item(i)
             if game.id == game_id:
                 return i
+        return None
 
     def on_game_stop(self, game):
         """Callback to remove the game from the running games"""
@@ -447,8 +477,7 @@ class Application(Gtk.Application):
                 "name": game["name"],
                 "runner": game["runner"],
                 "directory": game["directory"],
-            }
-            for game in game_list
+            } for game in game_list
         ]
         self._print(command_line, json.dumps(games, indent=2))
 
@@ -487,7 +516,7 @@ class Application(Gtk.Application):
             for path in steamapps_paths[platform]:
                 self._print(command_line, path)
 
-    def do_shutdown(self):
+    def do_shutdown(self):  # pylint: disable=arguments-differ
         logger.info("Shutting down Lutris")
         Gtk.Application.do_shutdown(self)
         if self.window:
