@@ -1,16 +1,23 @@
 """Widget generators and their signal handlers"""
-# pylint: disable=no-member
+# Standard Library
+# pylint: disable=no-member,too-many-public-methods
 import os
-from gi.repository import Gtk, Gdk
+from gettext import gettext as _
 
+# Third Party Libraries
+from gi.repository import Gdk, Gtk
+
+# Lutris Modules
 from lutris import settings, sysoptions
-from lutris.gui.widgets.common import VBox, Label, FileChooserEntry, EditableGrid
-from lutris.runners import import_runner, InvalidRunner
-from lutris.util.log import logger
+from lutris.gui.widgets.common import EditableGrid, FileChooserEntry, Label, VBox
+from lutris.gui.widgets.searchable_combobox import SearchableCombobox
+from lutris.runners import InvalidRunner, import_runner
 from lutris.util.jobs import AsyncCall
+from lutris.util.log import logger
 
 
 class ConfigBox(VBox):
+
     """Dynamically generate a vbox built upon on a python dict."""
 
     def __init__(self, game=None):
@@ -21,6 +28,9 @@ class ConfigBox(VBox):
         self.raw_config = None
         self.option_widget = None
         self.wrapper = None
+        self.tooltip_default = None
+        self.files = []
+        self.files_list_store = None
 
     def generate_top_info_box(self, text):
         """Add a top section with general help text for the current tab"""
@@ -43,10 +53,10 @@ class ConfigBox(VBox):
 
         help_box.show_all()
 
-    def generate_widgets(self, config_section):
+    def generate_widgets(self, config_section):  # noqa: C901 # pylint: disable=too-many-branches,too-many-statements
         """Parse the config dict and generates widget accordingly."""
         if not self.options:
-            no_options_label = Label("No options available")
+            no_options_label = Label(_("No options available"))
             no_options_label.set_halign(Gtk.Align.CENTER)
             no_options_label.set_valign(Gtk.Align.CENTER)
             self.pack_start(no_options_label, True, True, 0)
@@ -72,7 +82,7 @@ class ConfigBox(VBox):
             value = self.config.get(option_key)
             default = option.get("default")
 
-            if callable(option.get("choices")):
+            if callable(option.get("choices")) and option["type"] != "choice_with_search":
                 option["choices"] = option["choices"]()
             if callable(option.get("condition")):
                 option["condition"] = option["condition"]()
@@ -92,7 +102,7 @@ class ConfigBox(VBox):
             # Reset button
             reset_btn = Gtk.Button.new_from_icon_name("edit-clear", Gtk.IconSize.MENU)
             reset_btn.set_relief(Gtk.ReliefStyle.NONE)
-            reset_btn.set_tooltip_text("Reset option to global or " "default config")
+            reset_btn.set_tooltip_text(_("Reset option to global or default config"))
             reset_btn.connect(
                 "clicked",
                 self.on_reset_button_clicked,
@@ -113,10 +123,10 @@ class ConfigBox(VBox):
             helptext = option.get("help")
             if isinstance(self.tooltip_default, str):
                 helptext = helptext + "\n\n" if helptext else ""
-                helptext += "<b>Default</b>: " + self.tooltip_default
+                helptext += _("<b>Default</b>: ") + _(self.tooltip_default)
             if value != default and option_key not in self.raw_config:
                 helptext = helptext + "\n\n" if helptext else ""
-                helptext += (
+                helptext += _(
                     "<i>(Italic indicates that this option is "
                     "modified in a lower configuration level.)</i>"
                 )
@@ -140,8 +150,9 @@ class ConfigBox(VBox):
             hbox.pack_start(self.wrapper, True, True, 0)
             self.pack_start(hbox, False, False, 0)
 
-    def call_widget_generator(self, option, option_key, value, default):
+    def call_widget_generator(self, option, option_key, value, default):  # noqa: C901
         """Call the right generation method depending on option type."""
+        # pylint: disable=too-many-branches
         option_type = option["type"]
         option_size = option.get("size", None)
 
@@ -151,9 +162,7 @@ class ConfigBox(VBox):
             self.set_style_property("font-style", "italic", self.wrapper)
 
         if option_type == "choice":
-            self.generate_combobox(
-                option_key, option["choices"], option["label"], value, default
-            )
+            self.generate_combobox(option_key, option["choices"], option["label"], value, default)
 
         elif option_type == "choice_with_entry":
             self.generate_combobox(
@@ -164,6 +173,14 @@ class ConfigBox(VBox):
                 default,
                 has_entry=True,
             )
+        elif option_type == "choice_with_search":
+            self.generate_searchable_combobox(
+                option_key,
+                option["choices"],
+                option["label"],
+                value,
+                default,
+            )
 
         elif option_type == "bool":
             self.generate_checkbox(option, value)
@@ -172,9 +189,7 @@ class ConfigBox(VBox):
             self.generate_checkbox_with_callback(option, value)
             self.tooltip_default = "Enabled" if default else "Disabled"
         elif option_type == "range":
-            self.generate_range(
-                option_key, option["min"], option["max"], option["label"], value
-            )
+            self.generate_range(option_key, option["min"], option["max"], option["label"], value)
         elif option_type == "string":
             if "label" not in option:
                 raise ValueError("Option %s has no label" % option)
@@ -228,11 +243,7 @@ class ConfigBox(VBox):
         if value is True:
             checkbox.set_active(value)
 
-        checkbox.connect(
-            "notify::active",
-            self._on_toggle_with_callback,
-            option
-        )
+        checkbox.connect("notify::active", self._on_toggle_with_callback, option)
         checkbox.set_valign(Gtk.Align.CENTER)
         self.wrapper.pack_start(checkbox, False, False, 0)
         self.option_widget = checkbox
@@ -277,22 +288,32 @@ class ConfigBox(VBox):
         """Action triggered for entry 'changed' signal."""
         self.option_changed(entry, option_name, entry.get_text())
 
-    # ComboBox
-    def generate_combobox(
-        self, option_name, choices, label, value=None, default=None, has_entry=False
-    ):
-        """Generate a combobox (drop-down menu)."""
-        liststore = Gtk.ListStore(str, str)
+    def generate_searchable_combobox(self, option_name, choice_func, label, value, default):
+        """Generate a searchable combo box"""
+        combobox = SearchableCombobox(choice_func, value or default)
+        combobox.connect("changed", self.on_searchable_entry_changed, option_name)
+        self.wrapper.pack_start(Label(label), False, False, 0)
+        self.wrapper.pack_start(combobox, True, True, 0)
+        self.option_widget = combobox
+
+    def on_searchable_entry_changed(self, combobox, value, key):
+        self.option_changed(combobox, key, value)
+
+    def _populate_combobox_choices(self, liststore, choices, default):
         for choice in choices:
             if isinstance(choice, str):
-                choice = [choice, choice]
-            if choice[1] == default and not has_entry:
-                # Do not add default label to editable dropdowns since this gets
-                # added to the actual value.
-                liststore.append([choice[0] + "  (default)", default])
+                choice = (choice, choice)
+            if choice[1] == default:
+                liststore.append((_("%s (default)") % choice[0], choice[1]))
                 self.tooltip_default = choice[0]
             else:
                 liststore.append(choice)
+
+    # ComboBox
+    def generate_combobox(self, option_name, choices, label, value=None, default=None, has_entry=False):
+        """Generate a combobox (drop-down menu)."""
+        liststore = Gtk.ListStore(str, str)
+        self._populate_combobox_choices(liststore, choices, default)
         # With entry ("choice_with_entry" type)
         if has_entry:
             combobox = Gtk.ComboBox.new_with_model_and_entry(liststore)
@@ -314,7 +335,7 @@ class ConfigBox(VBox):
                 combobox.set_active_id(default)
 
         combobox.connect("changed", self.on_combobox_change, option_name)
-        combobox.connect("scroll-event", self.on_combobox_scroll)
+        combobox.connect("scroll-event", self._on_combobox_scroll)
         label = Label(label)
         combobox.set_valign(Gtk.Align.CENTER)
         self.wrapper.pack_start(label, False, False, 0)
@@ -322,30 +343,29 @@ class ConfigBox(VBox):
         self.option_widget = combobox
 
     @staticmethod
-    def on_combobox_scroll(combobox, event):
-        """Do not change options when scrolling
-        with cursor inside a ComboBox."""
+    def _on_combobox_scroll(combobox, _event):
+        """Prevents users from accidentally changing configuration values
+        while scrolling down dialogs.
+        """
         combobox.stop_emission_by_name("scroll-event")
         return False
 
     def on_combobox_change(self, combobox, option):
         """Action triggered on combobox 'changed' signal."""
-        if combobox.get_has_entry():
-            option_value = combobox.get_child().get_text()
+        list_store = combobox.get_model()
+        active = combobox.get_active()
+        option_value = None
+        if active < 0:
+            if combobox.get_has_entry():
+                option_value = combobox.get_child().get_text()
         else:
-            model = combobox.get_model()
-            active = combobox.get_active()
-            if active < 0:
-                return None
-            option_value = model[active][1]
+            option_value = list_store[active][1]
         self.option_changed(combobox, option, option_value)
 
     # Range
     def generate_range(self, option_name, min_val, max_val, label, value=None):
         """Generate a ranged spin button."""
-        adjustment = Gtk.Adjustment(
-            float(min_val), float(min_val), float(max_val), 1, 0, 0
-        )
+        adjustment = Gtk.Adjustment(float(min_val), float(min_val), float(max_val), 1, 0, 0)
         spin_button = Gtk.SpinButton()
         spin_button.set_adjustment(adjustment)
         if value:
@@ -367,7 +387,7 @@ class ConfigBox(VBox):
         option_name = option["option"]
         label = Label(option["label"])
         file_chooser = FileChooserEntry(
-            title="Select file",
+            title=_("Select file"),
             action=Gtk.FileChooserAction.OPEN,
             path=path,
             default_path=option.get("default_path")
@@ -411,14 +431,9 @@ class ConfigBox(VBox):
         if not path and self.game and self.game.runner:
             default_path = self.game.runner.working_dir
         directory_chooser = FileChooserEntry(
-            title="Select folder",
-            action=Gtk.FileChooserAction.SELECT_FOLDER,
-            path=path,
-            default_path=default_path
-        )
-        directory_chooser.entry.connect(
-            "changed", self._on_chooser_dir_set, option_name
+            title=_("Select folder"), action=Gtk.FileChooserAction.SELECT_FOLDER, path=path, default_path=default_path
         )
+        directory_chooser.entry.connect("changed", self._on_chooser_dir_set, option_name)
         directory_chooser.set_valign(Gtk.Align.CENTER)
         self.wrapper.pack_start(label, False, False, 0)
         self.wrapper.pack_start(directory_chooser, True, True, 0)
@@ -456,7 +471,7 @@ class ConfigBox(VBox):
         vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         label = Label(label + ":")
         label.set_halign(Gtk.Align.START)
-        button = Gtk.Button("Add files")
+        button = Gtk.Button(_("Add files"))
         button.connect("clicked", self.on_add_files_clicked, option_name, value)
         button.set_margin_left(10)
         vbox.pack_start(label, False, False, 5)
@@ -474,11 +489,9 @@ class ConfigBox(VBox):
             self.files_list_store.append([filename])
         cell_renderer = Gtk.CellRendererText()
         files_treeview = Gtk.TreeView(self.files_list_store)
-        files_column = Gtk.TreeViewColumn("Files", cell_renderer, text=0)
+        files_column = Gtk.TreeViewColumn(_("Files"), cell_renderer, text=0)
         files_treeview.append_column(files_column)
-        files_treeview.connect(
-            "key-press-event", self.on_files_treeview_keypress, option_name
-        )
+        files_treeview.connect("key-press-event", self.on_files_treeview_keypress, option_name)
         treeview_scroll = Gtk.ScrolledWindow()
         treeview_scroll.set_min_content_height(130)
         treeview_scroll.set_margin_left(10)
@@ -490,16 +503,16 @@ class ConfigBox(VBox):
         self.wrapper.pack_start(vbox, True, True, 0)
         self.option_widget = self.files_list_store
 
-    def on_add_files_clicked(self, widget, option_name, value):
+    def on_add_files_clicked(self, _widget, option_name, value):
         """Create and run multi-file chooser dialog."""
         dialog = Gtk.FileChooserDialog(
-            title="Select files",
+            title=_("Select files"),
             parent=None,
             action=Gtk.FileChooserAction.OPEN,
             buttons=(
-                "_Cancel",
+                _("_Cancel"),
                 Gtk.ResponseType.CANCEL,
-                "_Add",
+                _("_Add"),
                 Gtk.ResponseType.ACCEPT,
             ),
         )
@@ -507,10 +520,7 @@ class ConfigBox(VBox):
 
         first_file_dir = os.path.dirname(value[0]) if value else None
         dialog.set_current_folder(
-            first_file_dir
-            or self.game.directory
-            or self.config.get("game_path")
-            or os.path.expanduser("~")
+            first_file_dir or self.game.directory or self.config.get("game_path") or os.path.expanduser("~")
         )
         response = dialog.run()
         if response == Gtk.ResponseType.ACCEPT:
@@ -540,7 +550,7 @@ class ConfigBox(VBox):
                 self.raw_config[option].pop(row_index)
 
     @staticmethod
-    def on_query_tooltip(widget, x, y, keybmode, tooltip, text):
+    def on_query_tooltip(_widget, x, y, keybmode, tooltip, text):  # pylint: disable=unused-argument
         """Prepare a custom tooltip with a fixed width"""
         label = Label(text)
         label.set_use_markup(True)
@@ -565,7 +575,7 @@ class ConfigBox(VBox):
         reset_btn.set_visible(True)
         self.set_style_property("font-weight", "bold", wrapper)
 
-    def on_reset_button_clicked(self, btn, option, widget, wrapper):
+    def on_reset_button_clicked(self, btn, option, _widget, wrapper):
         """Clear option (remove from config, reset option widget)."""
         option_key = option["option"]
         current_value = self.config[option_key]
@@ -584,25 +594,20 @@ class ConfigBox(VBox):
         children = wrapper.get_children()
         for child in children:
             child.destroy()
-        self.call_widget_generator(
-            option, option_key, reset_value, option.get("default")
-        )
+        self.call_widget_generator(option, option_key, reset_value, option.get("default"))
         self.wrapper.show_all()
 
     @staticmethod
     def set_style_property(property_, value, wrapper):
         """Add custom style."""
         style_provider = Gtk.CssProvider()
-        style_provider.load_from_data(
-            "GtkHBox {{{}: {};}}".format(property_, value).encode()
-        )
+        style_provider.load_from_data("GtkHBox {{{}: {};}}".format(property_, value).encode())
         style_context = wrapper.get_style_context()
-        style_context.add_provider(
-            style_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
-        )
+        style_context.add_provider(style_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
 
 
 class GameBox(ConfigBox):
+
     def __init__(self, lutris_config, game):
         ConfigBox.__init__(self, game)
         self.lutris_config = lutris_config
@@ -622,7 +627,9 @@ class GameBox(ConfigBox):
 
 
 class RunnerBox(ConfigBox):
+
     """Configuration box for runner specific options"""
+
     def __init__(self, lutris_config, game=None):
         ConfigBox.__init__(self, game)
         self.lutris_config = lutris_config
@@ -634,14 +641,15 @@ class RunnerBox(ConfigBox):
             self.options = runner.get_runner_options()
 
         if lutris_config.level == "game":
-            self.generate_top_info_box(
+            self.generate_top_info_box(_(
                 "If modified, these options supersede the same options from "
                 "the base runner configuration."
-            )
+            ))
         self.generate_widgets("runner")
 
 
 class SystemBox(ConfigBox):
+
     def __init__(self, lutris_config):
         ConfigBox.__init__(self)
         self.lutris_config = lutris_config
@@ -653,15 +661,15 @@ class SystemBox(ConfigBox):
             self.options = sysoptions.system_options
 
         if lutris_config.game_config_id and runner_slug:
-            self.generate_top_info_box(
+            self.generate_top_info_box(_(
                 "If modified, these options supersede the same options from "
                 "the base runner configuration, which themselves supersede "
                 "the global preferences."
-            )
+            ))
         elif runner_slug:
-            self.generate_top_info_box(
+            self.generate_top_info_box(_(
                 "If modified, these options supersede the same options from "
                 "the global preferences."
-            )
+            ))
 
         self.generate_widgets("system")
