@@ -1,19 +1,26 @@
-"""Commonly used dialogs"""
+"""
+    Commonly used dialogs
+    isort:skip_file
+"""
+# Standard Library
 # pylint: disable=no-member
 import os
+from gettext import gettext as _
 
+# Third Party Libraries
+import gi
+gi.require_version("WebKit2", "4.0")
+from gi.repository import GLib, GObject, Gtk, WebKit2
+
+# Lutris Modules
 from lutris import api, pga, runtime, settings
 from lutris.gui.widgets.log_text_view import LogTextView
 from lutris.util import datapath
 from lutris.util.log import logger
 
-import gi
-gi.require_version("WebKit2", "4.0")
-
-from gi.repository import GLib, GObject, Gtk, WebKit2
-
 
 class Dialog(Gtk.Dialog):
+
     def __init__(self, title=None, parent=None, flags=0, buttons=None):
         super().__init__(title, parent, flags, buttons)
         self.set_border_width(10)
@@ -54,12 +61,12 @@ class GtkBuilderDialog(GObject.Object):
     def present(self):
         self.dialog.present()
 
-    def on_close(self, *args):
+    def on_close(self, *args):  # pylint: disable=unused-argument
         """Propagate the destroy event after closing the dialog"""
         self.dialog.destroy()
         self.emit("destroy")
 
-    def on_response(self, widget, response):
+    def on_response(self, widget, response):  # pylint: disable=unused-argument
         if response == Gtk.ResponseType.DELETE_EVENT:
             try:
                 self.dialog.hide()
@@ -71,11 +78,12 @@ class AboutDialog(GtkBuilderDialog):
     glade_file = "about-dialog.ui"
     dialog_object = "about_dialog"
 
-    def initialize(self):
+    def initialize(self):  # pylint: disable=arguments-differ
         self.dialog.set_version(settings.VERSION)
 
 
 class NoticeDialog(Gtk.MessageDialog):
+
     """Display a message to the user."""
 
     def __init__(self, message, parent=None):
@@ -86,6 +94,7 @@ class NoticeDialog(Gtk.MessageDialog):
 
 
 class ErrorDialog(Gtk.MessageDialog):
+
     """Display an error message."""
 
     def __init__(self, message, secondary=None, parent=None):
@@ -98,15 +107,14 @@ class ErrorDialog(Gtk.MessageDialog):
 
 
 class QuestionDialog(Gtk.MessageDialog):
+
     """Ask the user a question."""
 
     YES = Gtk.ResponseType.YES
     NO = Gtk.ResponseType.NO
 
     def __init__(self, dialog_settings):
-        super().__init__(
-            message_type=Gtk.MessageType.QUESTION, buttons=Gtk.ButtonsType.YES_NO
-        )
+        super().__init__(message_type=Gtk.MessageType.QUESTION, buttons=Gtk.ButtonsType.YES_NO)
         self.set_markup(dialog_settings["question"])
         self.set_title(dialog_settings["title"])
         if "widgets" in dialog_settings:
@@ -117,13 +125,14 @@ class QuestionDialog(Gtk.MessageDialog):
 
 
 class DirectoryDialog(Gtk.FileChooserDialog):
+
     """Ask the user to select a directory."""
 
     def __init__(self, message, parent=None):
         super().__init__(
             title=message,
             action=Gtk.FileChooserAction.SELECT_FOLDER,
-            buttons=("_Cancel", Gtk.ResponseType.CLOSE, "_OK", Gtk.ResponseType.OK),
+            buttons=(_("_Cancel"), Gtk.ResponseType.CLOSE, _("_OK"), Gtk.ResponseType.OK),
             parent=parent,
         )
         self.result = self.run()
@@ -132,17 +141,18 @@ class DirectoryDialog(Gtk.FileChooserDialog):
 
 
 class FileDialog(Gtk.FileChooserDialog):
+
     """Ask the user to select a file."""
 
     def __init__(self, message=None, default_path=None):
         self.filename = None
         if not message:
-            message = "Please choose a file"
+            message = _("Please choose a file")
         super().__init__(
             message,
             None,
             Gtk.FileChooserAction.OPEN,
-            ("_Cancel", Gtk.ResponseType.CANCEL, "_OK", Gtk.ResponseType.OK),
+            (_("_Cancel"), Gtk.ResponseType.CANCEL, _("_OK"), Gtk.ResponseType.OK),
         )
         if default_path and os.path.exists(default_path):
             self.set_current_folder(default_path)
@@ -155,6 +165,7 @@ class FileDialog(Gtk.FileChooserDialog):
 
 
 class InstallOrPlayDialog(Gtk.Dialog):
+
     def __init__(self, game_name):
         Gtk.Dialog.__init__(self, "%s is already installed" % game_name)
         self.connect("delete-event", lambda *x: self.destroy())
@@ -167,36 +178,37 @@ class InstallOrPlayDialog(Gtk.Dialog):
         vbox = Gtk.Box.new(Gtk.Orientation.VERTICAL, 6)
         self.get_content_area().add(vbox)
 
-        play_button = Gtk.RadioButton.new_with_label_from_widget(None, "Launch game")
+        play_button = Gtk.RadioButton.new_with_label_from_widget(None, _("Launch game"))
         play_button.connect("toggled", self.on_button_toggled, "play")
         vbox.pack_start(play_button, False, False, 0)
         install_button = Gtk.RadioButton.new_from_widget(play_button)
-        install_button.set_label("Install the game again")
+        install_button.set_label(_("Install the game again"))
         install_button.connect("toggled", self.on_button_toggled, "install")
         vbox.pack_start(install_button, False, False, 0)
 
-        confirm_button = Gtk.Button("OK")
+        confirm_button = Gtk.Button(_("OK"))
         confirm_button.connect("clicked", self.on_confirm)
         vbox.pack_start(confirm_button, False, False, 0)
 
         self.show_all()
         self.run()
 
-    def on_button_toggled(self, button, action):
+    def on_button_toggled(self, button, action):  # pylint: disable=unused-argument
         logger.debug("Action set to %s", action)
         self.action = action
 
-    def on_confirm(self, button):
+    def on_confirm(self, button):  # pylint: disable=unused-argument
         logger.debug("Action %s confirmed", self.action)
         self.action_confirmed = True
         self.destroy()
 
 
 class RuntimeUpdateDialog(Gtk.Dialog):
+
     """Dialog showing the progress of ongoing runtime update."""
 
     def __init__(self, parent=None):
-        Gtk.Dialog.__init__(self, "Runtime updating", parent=parent)
+        Gtk.Dialog.__init__(self, _("Runtime updating"), parent=parent)
         self.set_size_request(360, 104)
         self.set_border_width(12)
         progress_box = Gtk.Box()
@@ -210,7 +222,7 @@ class RuntimeUpdateDialog(Gtk.Dialog):
         GLib.timeout_add(200, self.on_runtime_check)
         self.show_all()
 
-    def on_runtime_check(self, *args, **kwargs):
+    def on_runtime_check(self, *args, **kwargs):  # pylint: disable=unused-argument
         self.progressbar.pulse()
         if not runtime.is_updating():
             self.response(Gtk.ResponseType.OK)
@@ -239,8 +251,8 @@ class PgaSourceDialog(GtkBuilderDialog):
         self.sources_treeview.append_column(uri_column)
         self.sources_treeview.set_model(self.sources_liststore)
         sources = pga.read_sources()
-        for index, source in enumerate(sources):
-            self.sources_liststore.append((source,))
+        for __, source in enumerate(sources):
+            self.sources_liststore.append((source, ))
 
         self.remove_source_button.set_sensitive(False)
         self.dialog.show_all()
@@ -253,31 +265,31 @@ class PgaSourceDialog(GtkBuilderDialog):
         pga.write_sources(self.sources_list)
         self.on_close(widget, data)
 
-    def on_add_source_button_clicked(self, widget, data=None):
+    def on_add_source_button_clicked(self, widget, data=None):  # pylint: disable=unused-argument
         chooser = Gtk.FileChooserDialog(
-            "Select directory",
+            _("Select directory"),
             self.dialog,
             Gtk.FileChooserAction.SELECT_FOLDER,
-            ("_Cancel", Gtk.ResponseType.CANCEL, "_OK", Gtk.ResponseType.OK),
+            (_("_Cancel"), Gtk.ResponseType.CANCEL, _("_OK"), Gtk.ResponseType.OK),
         )
         chooser.set_local_only(False)
         response = chooser.run()
         if response == Gtk.ResponseType.OK:
             uri = chooser.get_uri()
             if uri not in self.sources_list:
-                self.sources_liststore.append((uri,))
+                self.sources_liststore.append((uri, ))
         chooser.destroy()
 
-    def on_remove_source_button_clicked(self, widget, data=None):
+    def on_remove_source_button_clicked(self, widget, data=None):  # pylint: disable=unused-argument
         """Remove a source."""
         (model, treeiter) = self.sources_selection.get_selected()
         if treeiter:
             # TODO : Add confirmation
             model.remove(treeiter)
 
-    def on_sources_selection_changed(self, widget, data=None):
-        """Set sentivity of remove source button."""
-        (model, treeiter) = self.sources_selection.get_selected()
+    def on_sources_selection_changed(self, widget, data=None):  # pylint: disable=unused-argument
+        """Set sensitivity of remove source button."""
+        _, treeiter = self.sources_selection.get_selected()
         self.remove_source_button.set_sensitive(treeiter is not None)
 
 
@@ -285,8 +297,8 @@ class ClientLoginDialog(GtkBuilderDialog):
     glade_file = "dialog-lutris-login.ui"
     dialog_object = "lutris-login"
     __gsignals__ = {
-        "connected": (GObject.SignalFlags.RUN_LAST, None, (GObject.TYPE_PYOBJECT,)),
-        "cancel": (GObject.SignalFlags.RUN_LAST, None, (GObject.TYPE_PYOBJECT,)),
+        "connected": (GObject.SignalFlags.RUN_LAST, None, (GObject.TYPE_PYOBJECT, )),
+        "cancel": (GObject.SignalFlags.RUN_LAST, None, (GObject.TYPE_PYOBJECT, )),
     }
 
     def __init__(self, parent):
@@ -306,23 +318,23 @@ class ClientLoginDialog(GtkBuilderDialog):
         password = self.password_entry.get_text()
         return username, password
 
-    def on_username_entry_activate(self, widget):
+    def on_username_entry_activate(self, widget):  # pylint: disable=unused-argument
         if all(self.get_credentials()):
             self.on_connect(None)
         else:
             self.password_entry.grab_focus()
 
-    def on_password_entry_activate(self, widget):
+    def on_password_entry_activate(self, widget):  # pylint: disable=unused-argument
         if all(self.get_credentials()):
             self.on_connect(None)
         else:
             self.username_entry.grab_focus()
 
-    def on_connect(self, widget):
+    def on_connect(self, widget):  # pylint: disable=unused-argument
         username, password = self.get_credentials()
         token = api.connect(username, password)
         if not token:
-            NoticeDialog("Login failed", parent=self.parent)
+            NoticeDialog(_("Login failed"), parent=self.parent)
         else:
             self.emit("connected", username)
             self.dialog.destroy()
@@ -340,15 +352,15 @@ class NoInstallerDialog(Gtk.MessageDialog):
             0,
             Gtk.MessageType.ERROR,
             Gtk.ButtonsType.NONE,
-            "Unable to install the game",
+            _("Unable to install the game"),
         )
-        self.format_secondary_text("No installer is available for this game")
+        self.format_secondary_text(_("No installer is available for this game"))
         self.add_buttons(
-            "Configure manually",
+            _("Configure manually"),
             self.MANUAL_CONF,
-            "Write installer",
+            _("Write installer"),
             self.NEW_INSTALLER,
-            "Close",
+            _("Close"),
             self.EXIT,
         )
         self.result = self.run()
@@ -356,6 +368,7 @@ class NoInstallerDialog(Gtk.MessageDialog):
 
 
 class WebConnectDialog(Dialog):
+
     """Login form for external services"""
 
     def __init__(self, service, parent=None):
@@ -363,9 +376,7 @@ class WebConnectDialog(Dialog):
         self.context = WebKit2.WebContext.new()
         if "http_proxy" in os.environ:
             proxy = WebKit2.NetworkProxySettings.new(os.environ["http_proxy"])
-            self.context.set_network_proxy_settings(
-                WebKit2.NetworkProxyMode.CUSTOM, proxy
-            )
+            self.context.set_network_proxy_settings(WebKit2.NetworkProxyMode.CUSTOM, proxy)
         WebKit2.CookieManager.set_persistent_storage(
             self.context.get_cookie_manager(),
             service.cookies_path,
@@ -393,10 +404,11 @@ class WebConnectDialog(Dialog):
 
 
 class InstallerSourceDialog(Gtk.Dialog):
+
     """Show install script source"""
 
     def __init__(self, code, name, parent):
-        Gtk.Dialog.__init__(self, "Install script for {}".format(name), parent=parent)
+        Gtk.Dialog.__init__(self, _("Install script for {}").format(name), parent=parent)
         self.set_size_request(500, 350)
         self.set_border_width(0)
 
@@ -412,35 +424,34 @@ class InstallerSourceDialog(Gtk.Dialog):
         self.get_content_area().add(self.scrolled_window)
         self.scrolled_window.add(source_box)
 
-        close_button = Gtk.Button("OK")
+        close_button = Gtk.Button(_("OK"))
         close_button.connect("clicked", self.on_close)
         self.get_content_area().add(close_button)
 
         self.show_all()
 
-    def on_close(self, *args):
+    def on_close(self, *args):  # pylint: disable=unused-argument
         self.destroy()
 
 
 class DontShowAgainDialog(Gtk.MessageDialog):
+
     """Display a message to the user and offer an option not to display this dialog again."""
 
     def __init__(
-            self,
-            setting,
-            message,
-            secondary_message=None,
-            parent=None,
-            checkbox_message=None,
+        self,
+        setting,
+        message,
+        secondary_message=None,
+        parent=None,
+        checkbox_message=None,
     ):
 
         if settings.read_setting(setting) == "True":
             logger.info("Dialog %s dismissed by user", setting)
             return
 
-        super().__init__(
-            type=Gtk.MessageType.WARNING, buttons=Gtk.ButtonsType.OK, parent=parent
-        )
+        super().__init__(type=Gtk.MessageType.WARNING, buttons=Gtk.ButtonsType.OK, parent=parent)
 
         self.set_border_width(12)
         self.set_markup("<b>%s</b>" % message)
@@ -449,7 +460,7 @@ class DontShowAgainDialog(Gtk.MessageDialog):
             self.props.secondary_text = secondary_message
 
         if not checkbox_message:
-            checkbox_message = "Do not display this message again."
+            checkbox_message = _("Do not display this message again.")
 
         dont_show_checkbutton = Gtk.CheckButton(checkbox_message)
         dont_show_checkbutton.props.halign = Gtk.Align.CENTER
@@ -464,16 +475,19 @@ class DontShowAgainDialog(Gtk.MessageDialog):
 
 
 class WineNotInstalledWarning(DontShowAgainDialog):
+
     """Display a warning if Wine is not detected on the system"""
 
     def __init__(self, parent=None):
         super().__init__(
             "hide-wine-systemwide-install-warning",
-            "Wine is not installed on your system.",
-            secondary_message="Having Wine installed on your system guarantees that "
-            "Wine builds from Lutris will have all required dependencies.\n\nPlease "
-            "follow the instructions given in the <a "
-            "href='https://github.com/lutris/lutris/wiki/Wine-Dependencies'>Lutris Wiki</a> to "
-            "install Wine.",
+            _("Wine is not installed on your system."),
+            secondary_message=_(
+                "Having Wine installed on your system guarantees that "
+                "Wine builds from Lutris will have all required dependencies.\n\nPlease "
+                "follow the instructions given in the <a "
+                "href='https://github.com/lutris/lutris/wiki/Wine-Dependencies'>Lutris Wiki</a> to "
+                "install Wine."
+            ),
             parent=parent,
         )
