@@ -1,14 +1,22 @@
 """GUI dialog for reporting issues"""
-import os
+# Standard Library
 import json
+import os
+from gettext import gettext as _
+
+# Third Party Libraries
 from gi.repository import Gtk
+
+# Lutris Modules
 from lutris.gui.dialogs import NoticeDialog
-from lutris.util.linux import gather_system_info
 from lutris.gui.widgets.window import BaseApplicationWindow
+from lutris.util.linux import gather_system_info
 
 
 class IssueReportWindow(BaseApplicationWindow):
+
     """Window for collecting and sending issue reports"""
+
     def __init__(self, application):
         super().__init__(application)
 
@@ -16,15 +24,15 @@ class IssueReportWindow(BaseApplicationWindow):
         self.vbox.add(self.title_label)
 
         title_label = Gtk.Label()
-        title_label.set_markup("<b>Submit an issue</b>")
+        title_label.set_markup(_("<b>Submit an issue</b>"))
         self.vbox.add(title_label)
         self.vbox.add(Gtk.HSeparator())
 
-        issue_entry_label = Gtk.Label(
+        issue_entry_label = Gtk.Label(_(
             "Describe the problem you're having in the text box below. "
             "This information will be sent the Lutris team along with your system information."
             "You can also save this information locally if you are offline."
-        )
+        ))
         issue_entry_label.set_max_width_chars(80)
         issue_entry_label.set_property("wrap", True)
         self.vbox.add(issue_entry_label)
@@ -41,16 +49,10 @@ class IssueReportWindow(BaseApplicationWindow):
         action_buttons_alignment.add(self.action_buttons)
         self.vbox.pack_start(action_buttons_alignment, False, True, 0)
 
-        cancel_button = self.get_action_button(
-            "C_ancel",
-            handler=self.on_destroy
-        )
+        cancel_button = self.get_action_button(_("C_ancel"), handler=self.on_destroy)
         self.action_buttons.add(cancel_button)
 
-        save_button = self.get_action_button(
-            "_Save",
-            handler=self.on_save
-        )
+        save_button = self.get_action_button(_("_Save"), handler=self.on_save)
         self.action_buttons.add(save_button)
 
         self.show_all()
@@ -66,10 +68,10 @@ class IssueReportWindow(BaseApplicationWindow):
         """Signal handler for the save button"""
 
         save_dialog = Gtk.FileChooserDialog(
-            title="Select a location to save the issue",
+            title=_("Select a location to save the issue"),
             transient_for=self,
             action=Gtk.FileChooserAction.SELECT_FOLDER,
-            buttons=("_Cancel", Gtk.ResponseType.CLOSE, "_OK", Gtk.ResponseType.OK),
+            buttons=(_("_Cancel"), Gtk.ResponseType.CLOSE, _("_OK"), Gtk.ResponseType.OK),
         )
         save_dialog.connect("response", self.on_folder_selected)
         save_dialog.run()
@@ -85,5 +87,5 @@ class IssueReportWindow(BaseApplicationWindow):
         with open(issue_path, "w") as issue_file:
             json.dump(issue_info, issue_file, indent=2)
         dialog.destroy()
-        NoticeDialog("Issue saved in %s" % issue_path)
+        NoticeDialog(_("Issue saved in %s") % issue_path)
         self.destroy()
