@@ -1,10 +1,20 @@
-# pylint: disable=missing-docstring,no-member
+"""Dialog used to install versions of a runner"""
+import gettext
+# Standard Library
+# pylint: disable=no-member
 import os
 import random
+from collections import defaultdict
+from gettext import gettext as _
 
+# Third Party Libraries
 from gi.repository import GLib, Gtk
+
+# Lutris Modules
 from lutris import api, settings
+from lutris.game import Game
 from lutris.gui.dialogs import Dialog, ErrorDialog, QuestionDialog
+from lutris.pga import get_games_by_runner
 from lutris.util import jobs, system
 from lutris.util.downloader import Downloader
 from lutris.util.extract import extract_archive
@@ -12,31 +22,35 @@ from lutris.util.log import logger
 
 
 class RunnerInstallDialog(Dialog):
+
+    """Dialog displaying available runner version and downloads them"""
     COL_VER = 0
     COL_ARCH = 1
     COL_URL = 2
     COL_INSTALLED = 3
     COL_PROGRESS = 4
+    COL_USAGE = 5
 
     def __init__(self, title, parent, runner):
-        super().__init__(title, parent, 0, ("_OK", Gtk.ResponseType.OK))
-        width, height = (512, 480)
-        self.dialog_size = (width, height)
-        self.set_default_size(width, height)
-
+        super().__init__(title, parent, 0)
+        self.add_buttons(_("_OK"), Gtk.ButtonsType.OK)
         self.runner = runner
+        self.runner_info = {}
+        self.installing = {}
+        self.set_default_size(640, 480)
 
-        self.label = Gtk.Label("Waiting for response from %s" % (settings.SITE_URL))
-        self.vbox.pack_start(self.label, False, False, 18)
+        self.renderer_progress = Gtk.CellRendererProgress()
 
-        # Display a wait icon.
-        self.spinner = Gtk.Spinner()
-        self.vbox.pack_start(self.spinner, False, False, 18)
-        self.spinner.show()
-        self.spinner.start()
+        label = Gtk.Label.new(_("Waiting for response from %s") % (settings.SITE_URL))
+        self.vbox.pack_start(label, False, False, 18)
+
+        spinner = Gtk.Spinner(visible=True)
+        spinner.start()
+        self.vbox.pack_start(spinner, False, False, 18)
 
         self.show_all()
 
+        self.runner_store = Gtk.ListStore(str, str, str, bool, int, str)
         jobs.AsyncCall(api.get_runners, self.display_all_versions, self.runner)
 
     def display_all_versions(self, runner_info, error):
@@ -46,37 +60,36 @@ class RunnerInstallDialog(Dialog):
 
         self.runner_info = runner_info
         if not self.runner_info:
-            ErrorDialog(
-                "Unable to get runner versions. Check your internet connection."
-            )
+            ErrorDialog(_("Unable to get runner versions. Check your internet connection."))
             return
 
         for child_widget in self.vbox.get_children():
             if child_widget.get_name() not in "GtkBox":
                 child_widget.destroy()
 
-        label = Gtk.Label("%s version management" % self.runner_info["name"])
+        self.populate_store()
+
+        label = Gtk.Label.new(_("%s version management") % self.runner_info["name"])
         self.vbox.add(label)
-        self.runner_store = self.get_store()
         scrolled_window = Gtk.ScrolledWindow()
-        self.treeview = self.get_treeview(self.runner_store)
+        treeview = self.get_treeview(self.runner_store)
         self.installing = {}
         self.connect("response", self.on_destroy)
 
         scrolled_window.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         scrolled_window.set_shadow_type(Gtk.ShadowType.ETCHED_OUT)
-        scrolled_window.add(self.treeview)
+        scrolled_window.add(treeview)
 
         self.vbox.pack_start(scrolled_window, True, True, 14)
         self.show_all()
 
     def get_treeview(self, model):
+        """Return TreeeView widget"""
         treeview = Gtk.TreeView(model=model)
         treeview.set_headers_visible(False)
 
         renderer_toggle = Gtk.CellRendererToggle()
         renderer_text = Gtk.CellRendererText()
-        self.renderer_progress = Gtk.CellRendererProgress()
 
         installed_column = Gtk.TreeViewColumn(None, renderer_toggle, active=3)
         renderer_toggle.connect("toggled", self.on_installed_toggled)
@@ -97,52 +110,63 @@ class RunnerInstallDialog(Dialog):
             value=self.COL_PROGRESS,
             visible=self.COL_PROGRESS,
         )
-        progress_column.set_property("fixed-width", 60)
-        progress_column.set_property("min-width", 60)
-        progress_column.set_property("resizable", False)
+        progress_column.set_property("fixed-width", 120)
+        progress_column.set_property("min-width", 120)
+        progress_column.set_property("resizable", True)
         treeview.append_column(progress_column)
 
+        usage_column = Gtk.TreeViewColumn(None, renderer_text, text=self.COL_USAGE)
+        usage_column.set_property("min-width", 150)
+        treeview.append_column(usage_column)
+
         return treeview
 
-    def get_store(self):
-        liststore = Gtk.ListStore(str, str, str, bool, int)
-        for version_info in reversed(self.get_versions()):
-            version = version_info["version"]
-            architecture = version_info["architecture"]
-            progress = 0
-            is_installed = os.path.exists(self.get_runner_path(version, architecture))
-            liststore.append(
+    def get_usage_stats(self):
+        """Return the usage for each version"""
+        runner_games = get_games_by_runner(self.runner)
+        if self.runner == "wine":
+            runner_games += get_games_by_runner("winesteam")
+        version_usage = defaultdict(list)
+        for db_game in runner_games:
+            if not db_game["installed"]:
+                continue
+            game = Game(db_game["id"])
+            version = game.config.runner_config["version"]
+            version_usage[version].append(db_game["id"])
+        return version_usage
+
+    def populate_store(self):
+        """Return a ListStore populated with the runner versions"""
+        version_usage = self.get_usage_stats()
+        for version_info in reversed(self.runner_info["versions"]):
+            is_installed = os.path.exists(self.get_runner_path(version_info["version"], version_info["architecture"]))
+            games_using = version_usage.get("%(version)s-%(architecture)s" % version_info)
+            usage_summary = gettext.ngettext(
+                "In use by %d game",
+                "In use by %d games",
+                len(games_using)) % len(games_using) if games_using else _("Not in use")
+            self.runner_store.append(
                 [
-                    version_info["version"],
-                    version_info["architecture"],
-                    version_info["url"],
-                    is_installed,
-                    progress,
+                    version_info["version"], version_info["architecture"], version_info["url"], is_installed, 0,
+                    usage_summary if is_installed else ""
                 ]
             )
-        return liststore
-
-    def get_versions(self):
-        return self.runner_info["versions"]
 
     def get_runner_path(self, version, arch):
-        return os.path.join(
-            settings.RUNNER_DIR, self.runner, "{}-{}".format(version, arch)
-        )
+        """Return the local path where the runner is/will be installed"""
+        return os.path.join(settings.RUNNER_DIR, self.runner, "{}-{}".format(version, arch))
 
-    @staticmethod
-    def get_dest_path(row):
-        url = row[2]
-        filename = os.path.basename(url)
-        return os.path.join(settings.CACHE_DIR, filename)
+    def get_dest_path(self, row):
+        """Return temporary path where the runners should be downloaded to"""
+        return os.path.join(settings.CACHE_DIR, os.path.basename(row[self.COL_URL]))
 
-    def on_installed_toggled(self, widget, path):
+    def on_installed_toggled(self, _widget, path):
         row = self.runner_store[path]
         if row[self.COL_VER] in self.installing:
             confirm_dlg = QuestionDialog(
                 {
-                    "question": "Do you want to cancel the download?",
-                    "title": "Download starting",
+                    "question": _("Do you want to cancel the download?"),
+                    "title": _("Download starting"),
                 }
             )
             if confirm_dlg.result == confirm_dlg.YES:
@@ -153,12 +177,14 @@ class RunnerInstallDialog(Dialog):
             self.install_runner(row)
 
     def cancel_install(self, row):
+        """Cancel the installation of a runner version"""
         self.installing[row[self.COL_VER]].cancel()
         self.uninstall_runner(row)
         row[self.COL_PROGRESS] = 0
         self.installing.pop(row[self.COL_VER])
 
     def uninstall_runner(self, row):
+        """Uninstall a runner version"""
         version = row[self.COL_VER]
         arch = row[self.COL_ARCH]
         system.remove_folder(self.get_runner_path(version, arch))
@@ -170,15 +196,15 @@ class RunnerInstallDialog(Dialog):
             get_wine_versions.cache_clear()
 
     def install_runner(self, row):
-        url = row[2]
-        logger.debug("Downloading %s", url)
+        """Download and install a runner version"""
         dest_path = self.get_dest_path(row)
-        downloader = Downloader(url, dest_path, overwrite=True)
+        downloader = Downloader(row[self.COL_URL], dest_path, overwrite=True)
         GLib.timeout_add(100, self.get_progress, downloader, row)
         self.installing[row[self.COL_VER]] = downloader
         downloader.start()
 
     def get_progress(self, downloader, row):
+        """Update progress bar with download progress"""
         if downloader.state == downloader.CANCELLED:
             return False
         if downloader.state == downloader.ERROR:
@@ -187,23 +213,24 @@ class RunnerInstallDialog(Dialog):
         downloader.check_progress()
         percent_downloaded = downloader.progress_percentage
         if percent_downloaded >= 1:
-            row[4] = percent_downloaded
+            row[self.COL_PROGRESS] = percent_downloaded
             self.renderer_progress.props.pulse = -1
             self.renderer_progress.props.text = "%d %%" % int(percent_downloaded)
         else:
-            row[4] = 1
+            row[self.COL_PROGRESS] = 1
             self.renderer_progress.props.pulse = random.randint(1, 100)
-            self.renderer_progress.props.text = "Downloading…"
+            self.renderer_progress.props.text = _("Downloading…")
         if downloader.state == downloader.COMPLETED:
-            row[4] = 99
-            self.renderer_progress.props.text = "Extracting…"
+            row[self.COL_PROGRESS] = 99
+            self.renderer_progress.props.text = _("Extracting…")
             self.on_runner_downloaded(row)
             return False
         return True
 
     def on_runner_downloaded(self, row):
-        version = row[0]
-        architecture = row[1]
+        """Handler called when a runner version is downloaded"""
+        version = row[self.COL_VER]
+        architecture = row[self.COL_ARCH]
         logger.debug("Runner %s for %s has finished downloading", version, architecture)
         src = self.get_dest_path(row)
         dst = self.get_runner_path(version, architecture)
@@ -211,13 +238,14 @@ class RunnerInstallDialog(Dialog):
 
     @staticmethod
     def extract(src, dst, row):
+        """Extract a runner archive to a destination"""
         extract_archive(src, dst)
         return src, row
 
     def on_extracted(self, row_info, error):
         """Called when a runner archive is extracted"""
         if error or not row_info:
-            ErrorDialog("Failed to retrieve the runner archive", parent=self)
+            ErrorDialog(_("Failed to retrieve the runner archive"), parent=self)
             return
         src, row = row_info
         os.remove(src)
@@ -228,7 +256,6 @@ class RunnerInstallDialog(Dialog):
         if self.runner == "wine":
             logger.debug("Clearing wine version cache")
             from lutris.util.wine.wine import get_wine_versions
-
             get_wine_versions.cache_clear()
 
     def on_destroy(self, _dialog, _data=None):
@@ -236,6 +263,7 @@ class RunnerInstallDialog(Dialog):
         if self.installing:
             return True
         self.destroy()
+        return True
 
 
 if __name__ == "__main__":
