@@ -1,8 +1,11 @@
+# Standard Library
 import importlib
+
+# Lutris Modules
 from lutris import settings
 from lutris.util.log import logger
 
-MIGRATION_VERSION = 7  # Never decrease this number
+MIGRATION_VERSION = 8  # Never decrease this number
 
 # Replace deprecated migrations with empty lists
 MIGRATIONS = [
@@ -12,7 +15,8 @@ MIGRATIONS = [
     [],
     ["fix_playtime"],
     ["d9vk_to_dxvk"],
-    ["fix_playtime_type"]
+    ["fix_playtime_type"],
+    ["mess_to_mame"],
 ]
 
 
