@@ -1,32 +1,36 @@
+# Standard Library
 import os
+from gettext import gettext as _
+
+# Lutris Modules
 from lutris.runners.runner import Runner
 from lutris.util.display import DISPLAY_MANAGER
 
 
 class fsuae(Runner):
-    human_name = "FS-UAE"
-    description = "Amiga emulator"
+    human_name = _("FS-UAE")
+    description = _("Amiga emulator")
     platforms = [
-        "Amiga 500",
-        "Amiga 500+",
-        "Amiga 600",
-        "Amiga 1000",
-        "Amiga 1200",
-        "Amiga 1200",
-        "Amiga 4000",
-        "Amiga CD32",
-        "Commodore CDTV",
+        _("Amiga 500"),
+        _("Amiga 500+"),
+        _("Amiga 600"),
+        _("Amiga 1000"),
+        _("Amiga 1200"),
+        _("Amiga 1200"),
+        _("Amiga 4000"),
+        _("Amiga CD32"),
+        _("Commodore CDTV"),
     ]
     model_choices = [
-        ("Amiga 500", "A500"),
-        ("Amiga 500+ with 1 MB chip RAM", "A500+"),
-        ("Amiga 600 with 1 MB chip RAM", "A600"),
-        ("Amiga 1000 with 512 KB chip RAM", "A1000"),
-        ("Amiga 1200 with 2 MB chip RAM", "A1200"),
-        ("Amiga 1200 but with 68020 processor", "A1200/020"),
-        ("Amiga 4000 with 2 MB chip RAM and a 68040", "A4000/040"),
-        ("Amiga CD32", "CD32"),
-        ("Commodore CDTV", "CDTV"),
+        (_("Amiga 500"), "A500"),
+        (_("Amiga 500+ with 1 MB chip RAM"), "A500+"),
+        (_("Amiga 600 with 1 MB chip RAM"), "A600"),
+        (_("Amiga 1000 with 512 KB chip RAM"), "A1000"),
+        (_("Amiga 1200 with 2 MB chip RAM"), "A1200"),
+        (_("Amiga 1200 but with 68020 processor"), "A1200/020"),
+        (_("Amiga 4000 with 2 MB chip RAM and a 68040"), "A4000/040"),
+        (_("Amiga CD32"), "CD32"),
+        (_("Commodore CDTV"), "CDTV"),
     ]
     memory_choices = [
         ("0", "0"),
@@ -75,11 +79,15 @@ class fsuae(Runner):
     runner_executable = "fs-uae/fs-uae"
     game_options = [
         {
-            "option": "main_file",
-            "type": "file",
-            "label": "Boot disk",
-            "default_path": "game_path",
-            "help": (
+            "option":
+            "main_file",
+            "type":
+            "file",
+            "label":
+            _("Boot disk"),
+            "default_path":
+            "game_path",
+            "help": _(
                 "The main floppy disk file with the game data. \n"
                 "FS-UAE supports floppy images in multiple file formats: "
                 "ADF, IPF, DMS are the most common. ADZ (compressed ADF) "
@@ -87,36 +95,37 @@ class fsuae(Runner):
                 "Files ending in .hdf will be mounted as hard drives and "
                 "ISOs can be used for Amiga CD32 and CDTV models."
             ),
-        },
-        {
+        }, {
             "option": "disks",
             "type": "multiple",
-            "label": "Additionnal floppies",
+            "label": _("Additionnal floppies"),
             "default_path": "game_path",
-            "help": "The additional floppy disk image(s).",
-        },
-        {
+            "help": _("The additional floppy disk image(s)."),
+        }, {
             "option": "cdrom_image",
-            "label": "CD-Rom image",
+            "label": _("CD-Rom image"),
             "type": "file",
-            "help": "CD-ROM image to use on non CD32/CDTV models"
+            "help": _("CD-ROM image to use on non CD32/CDTV models")
         }
     ]
 
     runner_options = [
         {
             "option": "model",
-            "label": "Amiga model",
+            "label": _("Amiga model"),
             "type": "choice",
             "choices": model_choices,
             "default": "A500",
-            "help": "Specify the Amiga model you want to emulate.",
+            "help": _("Specify the Amiga model you want to emulate."),
         },
         {
-            "option": "kickstart_file",
-            "label": "Kickstart ROMs location",
-            "type": "file",
-            "help": (
+            "option":
+            "kickstart_file",
+            "label":
+            _("Kickstart ROMs location"),
+            "type":
+            "file",
+            "help": _(
                 "Choose the folder containing original Amiga kickstart "
                 "ROMs. Refer to FS-UAE documentation to find how to "
                 "acquire them. Without these, FS-UAE uses a bundled "
@@ -126,36 +135,39 @@ class fsuae(Runner):
         },
         {
             "option": "kickstart_ext_file",
-            "label": "Extended Kickstart location",
+            "label": _("Extended Kickstart location"),
             "type": "file",
-            "help": "Location of extended Kickstart used for CD32",
+            "help": _("Location of extended Kickstart used for CD32"),
         },
         {
             "option": "fmemory",
-            "label": "Fast Memory",
+            "label": _("Fast Memory"),
             "type": "choice",
             "choices": memory_choices,
             "default": "0",
-            "help": "Specify how much Fast Memory the Amiga model should have.",
+            "help": _("Specify how much Fast Memory the Amiga model should have."),
         },
         {
             "option": "fdvolume",
-            "label": "Floppy Drive Volume",
+            "label": _("Floppy Drive Volume"),
             "type": "choice",
             "choices": flsound_choices,
             "default": "0",
-            "help": (
-                "Set volume to 0 to disable floppy drive clicks "
-                "when the drive is empty. Max volume is 100."
-            )
+            "help": _("Set volume to 0 to disable floppy drive clicks "
+                      "when the drive is empty. Max volume is 100.")
         },
         {
-            "option": "fdspeed",
-            "label": "Floppy Drive Speed",
-            "type": "choice",
-            "choices": flspeed_choices,
-            "default": "100",
-            "help": (
+            "option":
+            "fdspeed",
+            "label":
+            _("Floppy Drive Speed"),
+            "type":
+            "choice",
+            "choices":
+            flspeed_choices,
+            "default":
+            "100",
+            "help": _(
                 "Set the speed of the emulated floppy drives, in percent. "
                 "For example, you can specify 800 to get an 8x increase in "
                 "speed. Use 0 to specify turbo mode. Turbo mode means that "
@@ -163,74 +175,79 @@ class fsuae(Runner):
             )
         },
         {
-            "option": "grafixcard",
-            "label": "Graphics Card",
-            "type": "choice",
-            "choices": gpucard_choices,
-            "default": "None",
-            "help": (
+            "option":
+            "grafixcard",
+            "label":
+            _("Graphics Card"),
+            "type":
+            "choice",
+            "choices":
+            gpucard_choices,
+            "default":
+            "None",
+            "help": _(
                 "Use this option to enable a graphics card. This option is none by default, in "
                 "which case only chipset graphics (OCS/ECS/AGA) support is available."
             )
         },
         {
-            "option": "grafixmemory",
-            "label": "Graphics Card RAM",
-            "type": "choice",
-            "choices": gpumem_choices,
-            "default": "0",
-            "help": (
+            "option":
+            "grafixmemory",
+            "label":
+            _("Graphics Card RAM"),
+            "type":
+            "choice",
+            "choices":
+            gpumem_choices,
+            "default":
+            "0",
+            "help": _(
                 "Override the amount of graphics memory on the graphics card. The 0 MB option is "
                 "not really valid, but exists for user interface reasons."
             )
         },
         {
             "option": "gfx_fullscreen_amiga",
-            "label": "Fullscreen (F12 + s to switch)",
+            "label": _("Fullscreen (F12 + s to switch)"),
             "type": "bool",
             "default": False,
         },
         {
             "option": "jitcompiler",
-            "label": "JIT Compiler",
+            "label": _("JIT Compiler"),
             "type": "bool",
             "default": False,
         },
         {
             "option": "gamemode",
-            "label": "Feral GameMode",
+            "label": _("Feral GameMode"),
             "type": "bool",
             "default": False,
-            "help": (
-                "Automatically uses Feral GameMode daemon if available."
-                "set to true to disable the feature."
-            )
+            "help": _("Automatically uses Feral GameMode daemon if available."
+                      "set to true to disable the feature.")
         },
         {
             "option": "govwarning",
-            "label": "CPU governor warning",
+            "label": _("CPU governor warning"),
             "type": "bool",
             "default": False,
-            "help": (
-                "Warn if running with a CPU governor other than performance."
-                "set to true to disable the warning."
-            )
+            "help":
+            _("Warn if running with a CPU governor other than performance."
+              "set to true to disable the warning.")
         },
         {
             "option": "bsdsocket",
-            "label": "UAE bsdsocket.library",
+            "label": _("UAE bsdsocket.library"),
             "type": "bool",
             "default": False,
         },
         {
             "option": "scanlines",
-            "label": "Scanlines display style",
+            "label": _("Scanlines display style"),
             "type": "bool",
             "default": False,
-            "help": (
-                "Activates a display filter adding scanlines to imitate "
-                "the displays of yesteryear."
-            ),
+            "help": _("Activates a display filter adding scanlines to imitate "
+                      "the displays of yesteryear."),
         },
     ]
 
@@ -274,11 +291,11 @@ class fsuae(Runner):
         amiga_model = self.runner_config.get("model")
         if amiga_model in ("CD32", "CDTV"):
             return "cdrom_drive"
-        elif disk_path.lower().endswith(".hdf"):
+        if disk_path.lower().endswith(".hdf"):
             return "hard_drive"
         return "floppy_drive"
 
-    def get_params(self):
+    def get_params(self):  # pylint: disable=too-many-branches
         params = []
         model = self.runner_config.get("model")
         fmemory = self.runner_config.get("fmemory")
