@@ -1,99 +1,106 @@
-# -*- coding: utf-8 -*-
+# Standard Library
 import os
+from gettext import gettext as _
+
+# Lutris Modules
 from lutris.runners.runner import Runner
 from lutris.util import system
 
 
 class o2em(Runner):
-    human_name = "O2EM"
-    description = "Magnavox Osyssey² Emulator"
+    human_name = _("O2EM")
+    description = _("Magnavox Osyssey² Emulator")
     platforms = (
-        'Magnavox Odyssey²',
-        'Phillips C52',
-        'Phillips Videopac+',
-        'Brandt Jopac',
+        _("Magnavox Odyssey²"),
+        _("Phillips C52"),
+        _("Phillips Videopac+"),
+        _("Brandt Jopac"),
     )
     bios_path = os.path.expanduser("~/.o2em/bios")
-    runner_executable = 'o2em/o2em'
+    runner_executable = "o2em/o2em"
 
     checksums = {
-        'o2rom': "562d5ebf9e030a40d6fabfc2f33139fd",
-        'c52': "f1071cdb0b6b10dde94d3bc8a6146387",
-        'jopac': "279008e4a0db2dc5f1c048853b033828",
-        'g7400': "79008e4a0db2dc5f1c048853b033828",
+        "o2rom": "562d5ebf9e030a40d6fabfc2f33139fd",
+        "c52": "f1071cdb0b6b10dde94d3bc8a6146387",
+        "jopac": "279008e4a0db2dc5f1c048853b033828",
+        "g7400": "79008e4a0db2dc5f1c048853b033828",
     }
 
     bios_choices = [
-        ("Magnavox Odyssey2", "o2rom"),
-        ("Phillips C52", "c52"),
-        ("Phillips Videopac+", "g7400"),
-        ("Brandt Jopac", "jopac")
+        (_("Magnavox Odyssey2"), "o2rom"),
+        (_("Phillips C52"), "c52"),
+        (_("Phillips Videopac+"), "g7400"),
+        (_("Brandt Jopac"), "jopac"),
     ]
     controller_choices = [
-        ("Disable", "0"),
-        ("Arrows keys and right shift", "1"),
-        ("W,S,A,D,SPACE", "2"),
-        ("Joystick", "3")
+        (_("Disable"), "0"),
+        (_("Arrows keys and right shift"), "1"),
+        (_("W,S,A,D,SPACE"), "2"),
+        (_("Joystick"), "3"),
+    ]
+    game_options = [
+        {
+            "option": "main_file",
+            "type": "file",
+            "label": _("ROM file"),
+            "default_path": "game_path",
+            "help": _("The game data, commonly called a ROM image."),
+        }
     ]
-    game_options = [{
-        "option": "main_file",
-        "type": "file",
-        "label": "ROM file",
-        "default_path": 'game_path',
-        'help': "The game data, commonly called a ROM image."
-    }]
     runner_options = [
         {
             "option": "bios",
             "type": "choice",
             "choices": bios_choices,
-            "label": "Bios",
-            'default': 'o2rom',
+            "label": _("Bios"),
+            "default": "o2rom",
         },
         {
             "option": "controller1",
             "type": "choice",
             "choices": controller_choices,
-            "label": "First controller",
-            'default': '2',
+            "label": _("First controller"),
+            "default": "2",
         },
         {
             "option": "controller2",
             "type": "choice",
             "choices": controller_choices,
-            "label": "Second controller",
-            'default': '1',
+            "label": _("Second controller"),
+            "default": "1",
         },
         {
             "option": "fullscreen",
             "type": "bool",
-            "label": "Fullscreen",
-            'default': False,
+            "label": _("Fullscreen"),
+            "default": False,
         },
         {
             "option": "scanlines",
             "type": "bool",
-            "label": "Scanlines display style",
-            'default': False,
-            'help': ("Activates a display filter adding scanlines to imitate "
-                     "the displays of yesteryear.")
-        }
+            "label": _("Scanlines display style"),
+            "default": False,
+            "help": _("Activates a display filter adding scanlines to imitate "
+                      "the displays of yesteryear."),
+        },
     ]
 
     def get_platform(self):
-        bios = self.runner_config.get('bios')
+        bios = self.runner_config.get("bios")
         if bios:
             for i, b in enumerate(self.bios_choices):
                 if b[1] == bios:
                     return self.platforms[i]
-        return ''
+        return ""
 
     def install(self, version=None, downloader=None, callback=None):
+
         def on_runner_installed(*args):
             if not system.path_exists(self.bios_path):
                 os.makedirs(self.bios_path)
             if callback:
                 callback()
+
         super(o2em, self).install(version, downloader, on_runner_installed)
 
     def play(self):
@@ -109,11 +116,11 @@ class o2em(Runner):
             arguments.append("-s1=%s" % self.runner_config["controller1"])
         if "controller2" in self.runner_config:
             arguments.append("-s2=%s" % self.runner_config["controller2"])
-        rom_path = self.game_config.get('main_file') or ''
+        rom_path = self.game_config.get("main_file") or ""
         if not system.path_exists(rom_path):
-            return {'error': 'FILE_NOT_FOUND', 'file': rom_path}
+            return {"error": "FILE_NOT_FOUND", "file": rom_path}
         romdir = os.path.dirname(rom_path)
         romfile = os.path.basename(rom_path)
         arguments.append("-romdir=%s/" % romdir)
         arguments.append(romfile)
-        return {'command': [self.get_executable()] + arguments}
+        return {"command": [self.get_executable()] + arguments}
