@@ -1,29 +1,29 @@
+# Standard Library
+from gettext import gettext as _
+
+# Lutris Modules
 from lutris.runners.runner import Runner
 from lutris.util import system
 
 
 class ppsspp(Runner):
-    human_name = "PPSSPP"
-    description = "Sony PSP emulator"
-    platforms = ["Sony PlayStation Portable"]
+    human_name = _("PPSSPP")
+    description = _("Sony PSP emulator")
+    platforms = [_("Sony PlayStation Portable")]
     runner_executable = "ppsspp/PPSSPPSDL"
-    game_options = [
-        {
-            "option": "main_file",
-            "type": "file",
-            "label": "ISO file",
-            "default_path": "game_path",
-        }
-    ]
+    game_options = [{
+        "option": "main_file",
+        "type": "file",
+        "label": _("ISO file"),
+        "default_path": "game_path",
+    }]
 
-    runner_options = [
-        {
-            "option": "fullscreen",
-            "type": "bool",
-            "label": "Fullscreen",
-            "default": False,
-        }
-    ]
+    runner_options = [{
+        "option": "fullscreen",
+        "type": "bool",
+        "label": _("Fullscreen"),
+        "default": False,
+    }]
 
     def play(self):
         arguments = [self.get_executable()]
