@@ -1,8 +1,12 @@
 """Runtime handling module"""
+# Standard Library
 import os
 import time
 
+# Third Party Libraries
 from gi.repository import GLib
+
+# Lutris Modules
 from lutris.settings import RUNTIME_DIR, RUNTIME_URL
 from lutris.util import http, jobs, system
 from lutris.util.downloader import Downloader
@@ -15,6 +19,7 @@ DEFAULT_RUNTIME = "Ubuntu-18.04"
 
 
 class Runtime:
+
     """Class for manipulating runtime folders"""
 
     def __init__(self, name, updater):
@@ -38,7 +43,7 @@ class Runtime:
         """Set the creation and modification time to now"""
         if not system.path_exists(self.local_runtime_path):
             logger.error("No local runtime path in %s", self.local_runtime_path)
-            return None
+            return
         os.utime(self.local_runtime_path)
 
     def should_update(self, remote_updated_at):
@@ -62,9 +67,7 @@ class Runtime:
     def download(self, remote_runtime_info):
         """Downloads a runtime locally"""
         remote_updated_at = remote_runtime_info["created_at"]
-        remote_updated_at = time.strptime(
-            remote_updated_at[: remote_updated_at.find(".")], "%Y-%m-%dT%H:%M:%S"
-        )
+        remote_updated_at = time.strptime(remote_updated_at[:remote_updated_at.find(".")], "%Y-%m-%dT%H:%M:%S")
         if not self.should_update(remote_updated_at):
             return None
 
@@ -103,17 +106,17 @@ class Runtime:
         system.remove_folder(initial_path)
 
         # Extract the runtime archive
-        jobs.AsyncCall(
-            extract_archive, self.on_extracted, path, RUNTIME_DIR, merge_single=False
-        )
+        jobs.AsyncCall(extract_archive, self.on_extracted, path, RUNTIME_DIR, merge_single=False)
+        return False
 
     def on_extracted(self, result, error):
         """Callback method when a runtime has extracted"""
         if error:
             logger.error("Runtime update failed")
             logger.error(error)
-            return
+            return False
         archive_path, _destination_path = result
+        logger.debug("Deleting runtime archive %s", archive_path)
         os.unlink(archive_path)
         self.set_updated_at()
         self.updater.notify_finish(self)
@@ -121,6 +124,7 @@ class Runtime:
 
 
 class RuntimeUpdater:
+
     """Class handling the runtime updates"""
 
     current_updates = 0
@@ -160,9 +164,8 @@ class RuntimeUpdater:
 
             # Skip 32bit runtimes on 64 bit systems except the main runtime
             if (
-                    runtime["architecture"] == "i386"
-                    and system.LINUX_SYSTEM.is_64_bit
-                    and not runtime["name"].startswith(("Ubuntu", "lib32"))
+                runtime["architecture"] == "i386" and system.LINUX_SYSTEM.is_64_bit
+                and not runtime["name"].startswith(("Ubuntu", "lib32"))
             ):
                 logger.debug(
                     "Skipping runtime %s for %s",
@@ -206,16 +209,11 @@ def get_env(version=None, prefer_system_libs=False, wine_path=None):
     return {
         key: value
         for key, value in {
-            "STEAM_RUNTIME": os.path.join(RUNTIME_DIR, "steam") if not RUNTIME_DISABLED else None,
-            "LD_LIBRARY_PATH": ":".join(
-                get_paths(
-                    version=version,
-                    prefer_system_libs=prefer_system_libs,
-                    wine_path=wine_path
-                )
-            ),
-        }.items()
-        if value
+            "STEAM_RUNTIME":
+            os.path.join(RUNTIME_DIR, "steam") if not RUNTIME_DISABLED else None,
+            "LD_LIBRARY_PATH":
+            ":".join(get_paths(version=version, prefer_system_libs=prefer_system_libs, wine_path=wine_path)),
+        }.items() if value
     }
 
 
@@ -274,11 +272,7 @@ def get_runtime_paths(version=None, prefer_system_libs=True, wine_path=None):
 def get_paths(version=None, prefer_system_libs=True, wine_path=None):
     """Return a list of paths containing the runtime libraries."""
     if not RUNTIME_DISABLED:
-        paths = get_runtime_paths(
-            version=version,
-            prefer_system_libs=prefer_system_libs,
-            wine_path=wine_path
-        )
+        paths = get_runtime_paths(version=version, prefer_system_libs=prefer_system_libs, wine_path=wine_path)
     else:
         paths = []
     if os.environ.get("LD_LIBRARY_PATH"):
