@@ -1,12 +1,16 @@
 """Steam for Windows service"""
+from gettext import gettext as _
+
+# Lutris Modules
 from lutris.services.steam import SteamSyncer
 
-NAME = "Steam for Windows"
+NAME = _("Steam for Windows")
 ICON = "winesteam"
 ONLINE = False
 
 
 class WineSteamSyncer(SteamSyncer):
+
     """Sync games with Steam for Windows"""
     platform = "windows"
 
