@@ -1,20 +1,24 @@
 """XDG applications service"""
 
+# Standard Library
 import os
+import re
 import shlex
 import subprocess
-import re
+from gettext import gettext as _
 
+# Third Party Libraries
 from gi.repository import Gio
 
+# Lutris Modules
 from lutris import pga
+from lutris.config import LutrisConfig
+from lutris.services.service_game import ServiceGame
 from lutris.util import system
 from lutris.util.log import logger
 from lutris.util.strings import slugify
-from lutris.config import LutrisConfig
-from lutris.services.service_game import ServiceGame
 
-NAME = "Desktop games"
+NAME = _("Desktop games")
 ICON = "linux"
 ONLINE = False
 
@@ -32,6 +36,7 @@ def get_appid(app):
 
 
 class XDGGame(ServiceGame):
+
     """XDG game (Linux game with a desktop launcher)"""
 
     store = "xdg"
@@ -80,9 +85,7 @@ class XDGGame(ServiceGame):
         """Return a tuple with absolute command path and an argument string"""
         command = shlex.split(app.get_commandline())
         # remove %U etc. and change %% to % in arguments
-        args = list(
-            map(lambda arg: re.sub("%[^%]", "", arg).replace("%%", "%"), command[1:])
-        )
+        args = list(map(lambda arg: re.sub("%[^%]", "", arg).replace("%%", "%"), command[1:]))
         exe = command[0]
         if not exe.startswith("/"):
             exe = system.find_executable(exe)
@@ -95,6 +98,7 @@ class XDGGame(ServiceGame):
 
 
 class XDGSyncer:
+
     """Sync games available in a XDG compliant menu to Lutris"""
 
     ignored_games = (
@@ -133,9 +137,7 @@ class XDGSyncer:
     @property
     def lutris_games(self):
         """Iterates through Lutris games imported from XDG"""
-        for game in pga.get_games_where(
-                runner=XDGGame.runner, installer_slug=XDGGame.installer_slug, installed=1
-        ):
+        for game in pga.get_games_where(runner=XDGGame.runner, installer_slug=XDGGame.installer_slug, installed=1):
             yield game
 
     @classmethod
@@ -143,13 +145,15 @@ class XDGSyncer:
         """Returns whether a XDG game is importable to Lutris"""
         appid = get_appid(app)
         executable = app.get_executable() or ""
-        if any([
+        if any(
+            [
                 app.get_nodisplay() or app.get_is_hidden(),  # App is hidden
                 not executable,  # Check app has an executable
                 appid.startswith("net.lutris"),  # Skip lutris created shortcuts
                 appid.lower() in map(str.lower, cls.ignored_games),  # game blacklisted
                 executable.lower() in cls.ignored_executables,  # exe blacklisted
-        ]):
+            ]
+        ):
             return False
 
         # must be in Game category
@@ -159,11 +163,7 @@ class XDGSyncer:
             return False
 
         # contains a blacklisted category
-        if bool([
-                category
-                for category in categories
-                if category in map(str.lower, cls.ignored_categories)
-        ]):
+        if bool([category for category in categories if category in map(str.lower, cls.ignored_categories)]):
             return False
         return True
 
