@@ -1,5 +1,8 @@
-import time
+# Standard Library
 import sqlite3
+import time
+
+# Lutris Modules
 from lutris.util.log import logger
 
 # Number of attempts to retry failed queries
@@ -7,15 +10,17 @@ DB_RETRIES = 5
 
 
 class db_cursor(object):
+
     def __init__(self, db_path):
         self.db_path = db_path
+        self.db_conn = None
 
     def __enter__(self):
         self.db_conn = sqlite3.connect(self.db_path)
         cursor = self.db_conn.cursor()
         return cursor
 
-    def __exit__(self, type, value, traceback):
+    def __exit__(self, _type, value, traceback):
         self.db_conn.commit()
         self.db_conn.close()
 
@@ -32,12 +37,9 @@ def cursor_execute(cursor, query, params=None):
             i += 1
             if i == DB_RETRIES:
                 raise
-            else:
-                logger.error(
-                    "SQL query '%s' failed. %d retries remaining", query, DB_RETRIES - i
-                )
-                logger.error(ex)
-                time.sleep(1)
+            logger.error("SQL query '%s' failed. %d retries remaining", query, DB_RETRIES - i)
+            logger.error(ex)
+            time.sleep(1)
 
 
 def db_insert(db_path, table, fields):
@@ -48,12 +50,11 @@ def db_insert(db_path, table, fields):
         try:
             cursor_execute(
                 cursor,
-                "insert into {0}({1}) values ({2})".format(
-                    table, columns, placeholders
-                ),
+                "insert into {0}({1}) values ({2})".format(table, columns, placeholders),
                 field_values,
             )
         except sqlite3.IntegrityError:
+            logger.exception("Uh oh, an integrity error has occurred!")
             raise
         inserted_id = cursor.lastrowid
     return inserted_id
@@ -67,7 +68,7 @@ def db_update(db_path, table, updated_fields, where):
     field_values = tuple(updated_fields.values())
 
     condition_field = "{0}=?".format(where[0])
-    condition_value = (where[1],)
+    condition_value = (where[1], )
 
     with db_cursor(db_path) as cursor:
         query = "UPDATE {0} SET {1} WHERE {2}".format(table, columns, condition_field)
@@ -76,9 +77,7 @@ def db_update(db_path, table, updated_fields, where):
 
 def db_delete(db_path, table, field, value):
     with db_cursor(db_path) as cursor:
-        cursor_execute(
-            cursor, "delete from {0} where {1}=?".format(table, field), (value,)
-        )
+        cursor_execute(cursor, "delete from {0} where {1}=?".format(table, field), (value, ))
 
 
 def db_select(db_path, table, fields=None, condition=None):
@@ -95,7 +94,7 @@ def db_select(db_path, table, fields=None, condition=None):
                 placeholders = ", ".join("?" * len(condition_value))
                 where_condition = " where {} in (" + placeholders + ")"
             else:
-                condition_value = (condition_value,)
+                condition_value = (condition_value, )
                 where_condition = " where {}=?"
             query = query + where_condition
             query = query.format(columns, table, condition_field)
