@@ -1,7 +1,9 @@
 """Handle Steam configuration"""
+# Standard Library
 import os
 from collections import OrderedDict, defaultdict
 
+# Lutris Modules
 from lutris.util import system
 from lutris.util.log import logger
 from lutris.util.steam.vdf import vdf_parse
@@ -42,16 +44,13 @@ def read_config(steam_data_dir):
     with open(config_filename, "r") as steam_config_file:
         config = vdf_parse(steam_config_file, {})
     try:
-        return get_entry_case_insensitive(
-            config,
-            ["InstallConfigStore", "Software", "Valve", "Steam"]
-        )
+        return get_entry_case_insensitive(config, ["InstallConfigStore", "Software", "Valve", "Steam"])
     except KeyError as ex:
         logger.error("Steam config %s is empty: %s", config_filename, ex)
 
 
 def get_steamapps_paths_for_platform(platform_name):
-    from lutris.runners import winesteam, steam
+    from lutris.runners import winesteam, steam  # pylint: disable=import-outside-toplevel
 
     runners = {"linux": steam.steam, "windows": winesteam.winesteam}
     runner = runners[platform_name]()
