@@ -1,9 +1,9 @@
 """System utilities"""
 import hashlib
-import signal
 import os
 import re
 import shutil
+import signal
 import string
 import subprocess
 
@@ -11,7 +11,7 @@ from lutris.util.linux import LINUX_SYSTEM
 from lutris.util.log import logger
 
 
-def execute(command, env=None, cwd=None, log_errors=False, quiet=False, shell=False):
+def execute(command, env=None, cwd=None, log_errors=False, quiet=False, shell=False, timeout=None):
     """
         Execute a system command and return its results.
 
@@ -21,6 +21,7 @@ def execute(command, env=None, cwd=None, log_errors=False, quiet=False, shell=Fa
             cwd (str): Working directory
             log_errors (bool): Pipe stderr to stdout (might cause slowdowns)
             quiet (bool): Do not display log messages
+            timeout (int): Number of seconds the program is allowed to run, disabled by default
 
         Returns:
             str: stdout output
@@ -29,10 +30,10 @@ def execute(command, env=None, cwd=None, log_errors=False, quiet=False, shell=Fa
     # Check if the executable exists
     if not command:
         logger.error("No executable provided!")
-        return
+        return ""
     if os.path.isabs(command[0]) and not path_exists(command[0]):
         logger.error("No executable found in %s", command)
-        return
+        return ""
 
     if not quiet:
         logger.debug("Executing %s", " ".join([str(i) for i in command]))
@@ -55,10 +56,13 @@ def execute(command, env=None, cwd=None, log_errors=False, quiet=False, shell=Fa
             stderr=subprocess.PIPE if log_errors else subprocess.DEVNULL,
             env=existing_env,
             cwd=cwd,
-        ).communicate()
+        ).communicate(timeout=timeout)
     except (OSError, TypeError) as ex:
         logger.error("Could not run command %s (env: %s): %s", command, env, ex)
-        return
+        return ""
+    except subprocess.TimeoutExpired:
+        logger.error("Command %s after %s seconds", command, timeout)
+        return ""
     if stderr and log_errors:
         logger.error(stderr)
     return stdout.decode(errors="replace").strip()
@@ -156,9 +160,7 @@ def substitute(string_template, variables):
     # Replace the dashes with underscores in the mapping and template
     variables = dict((k.replace("-", "_"), v) for k, v in variables.items())
     for identifier in identifiers:
-        string_template = string_template.replace(
-            "${}".format(identifier), "${}".format(identifier.replace("-", "_"))
-        )
+        string_template = string_template.replace("${}".format(identifier), "${}".format(identifier.replace("-", "_")))
 
     template = string.Template(string_template)
     if string_template in list(variables.keys()):
@@ -184,9 +186,7 @@ def merge_folders(source, destination):
             # logger.debug("Copying %s", filename)
             if not os.path.exists(dst_abspath):
                 os.makedirs(dst_abspath)
-            shutil.copy(
-                os.path.join(dirpath, filename), os.path.join(dst_abspath, filename)
-            )
+            shutil.copy(os.path.join(dirpath, filename), os.path.join(dst_abspath, filename))
 
 
 def remove_folder(path):
@@ -202,8 +202,7 @@ def remove_folder(path):
     try:
         shutil.rmtree(path)
     except OSError as ex:
-        errno, message = ex.args
-        logger.error("Failed to remove folder %s: %s (Error code %s)", path, message, errno)
+        logger.error("Failed to remove folder %s: %s (Error code %s)", path, ex.strerror, ex.errno)
         return False
     return True
 
@@ -305,16 +304,19 @@ def reverse_expanduser(path):
     return path
 
 
-def path_exists(path, check_symlinks=False):
+def path_exists(path, check_symlinks=False, exclude_empty=False):
     """Wrapper around system.path_exists that doesn't crash with empty values
 
     Params:
         path (str): File to the file to check
         check_symlinks (bool): If the path is a broken symlink, return False
+        exclude_empty (bool): If true, consider 0 bytes files as non existing
     """
     if not path:
         return False
     if os.path.exists(path):
+        if exclude_empty:
+            return os.stat(path).st_size > 0
         return True
     if os.path.islink(path):
         logger.warning("%s is a broken link", path)
@@ -341,6 +343,7 @@ def run_once(function):
         if first_run:
             first_run = False
             return function(*args)
+
     return fn_wrapper
 
 
